@@ -375,6 +375,14 @@ property in Prima::Widget, Prima::Application::showHint is another layer of
 hint visibility control - if it is 0, all hint actions are disabled,
 disregarding C<::showHint> value in widgets.
 
+=item skin SCALAR
+
+Exactly same as L<Prima::Widget/skin>, but is mentioned here because
+it is possible to change the whole application skin by changing this property,
+f ex like this:
+
+   use Prima::Application skin => 'flat';
+
 =item textDirection BOOLEAN
 
 Contains preferred text direction, initially calculated from the preferred
@@ -849,7 +857,7 @@ program, for example, inside a long calculation cycle.
 yield(1) though is adapted exactly for external implementation of event loops;
 it does exactly the same as yeild(0), but if there are no events, it sleeps
 until there comes at least one, processes it, and then returns. The return
-value is 0 if the application doesn't need more event processins, because of
+value is 0 if the application doesn't need more event processings, because of
 shutting down.  The corresponding code will be
 
 	while ( yield(1)) {
