@@ -17,11 +17,16 @@ use Carp;
 use Prima qw(StdBitmap);
 
 package Prima::AbstractButton;
-use base qw(Prima::Widget Prima::Widget::MouseScroller);
+use base qw(
+	Prima::Widget
+	Prima::Widget::MouseScroller
+	Prima::Widget::Fader
+);
 
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	Check => nt::Default,
 );
 
@@ -38,6 +43,8 @@ sub profile_default
 		selectable   => 1,
 		autoHeight   => 1,
 		autoWidth    => 1,
+		autoShaping  => 0,
+		buffered     => 1,
 	}
 }
 
@@ -82,13 +89,36 @@ sub init
 {
 	my $self = shift;
 	my %profile = $self-> SUPER::init(@_);
-	$self-> { hotKey}  = $profile{ hotKey};
-	$self-> { pressed} = $profile{ pressed};
-	$self-> { autoHeight} = $profile{ autoHeight};
-	$self-> { autoWidth}  = $profile{ autoWidth};
+	$self-> {$_} = $profile{$_} for qw(autoWidth autoHeight hotKey pressed autoShaping);
 	return %profile;
 }
 
+sub skin
+{
+	return $_[0]->SUPER::skin unless $#_;
+	my $self = shift;
+	$self->SUPER::skin($_[1]);
+	if ($self->SUPER::skin eq 'flat') {
+		$self->update_shape if $self->autoShaping;
+	} else {
+		$self->shape(undef) if $self->autoShaping;
+	}
+	$self->repaint;
+}
+
+sub fader_current_color
+{
+	my ( $self, $color) = @_;
+	$color = $self->map_color($color);
+	if ( $self->{hilite}) {
+		return $self-> prelight_color($color);
+	} elsif ( defined ( my $f = $self->fader_current_value)) {
+		return cl::blend( $color, $self-> prelight_color($color), $f);
+	} else {
+		return $color;
+	}
+}
+
 sub cancel_transaction
 {
 	my $self = $_[0];
@@ -100,6 +130,8 @@ sub cancel_transaction
 	}
 }
 
+sub on_size { $_[0]->update_shape if $_[0]->skin eq 'flat' and $_[0]->autoShaping }
+
 sub on_keydown
 {
 	my ( $self, $code, $key, $mod, $repeat) = @_;
@@ -206,25 +238,30 @@ sub on_mousemove
 	$self-> notify(q(Click));
 }
 
+sub on_fadein
+{
+	my ( $self, $ends_okay ) = @_;
+	if ($ends_okay) {
+		$self->{hilite} = 1;
+		$self->repaint;
+	}
+}
+
 sub on_mouseenter
 {
 	my $self = $_[0];
-	if (
+	$self-> fader_in_mouse_enter if
 		!$self-> {spaceTransaction} &&
 		!$self-> {mouseTransaction} &&
-		$self-> enabled
-	) {
-		$self-> {hilite} = 1;
-		$self-> repaint;
-	}
+		$self-> enabled;
 }
 
 sub on_mouseleave
 {
-	my $self = $_[0];
-	if ( $self-> {hilite}) {
+	my $self = shift;
+	if ( $self-> enabled ) {
+		$self-> fader_out_mouse_leave;
 		undef $self-> {hilite};
-		$self-> repaint;
 	}
 }
 
@@ -232,6 +269,7 @@ sub on_mouseleave
 sub on_fontchanged
 {
 	$_[0]-> check_auto_size;
+	$_[0]-> update_shape if $_[0]->skin eq 'flat' and $_[0]->autoShaping;
 }
 
 sub draw_veil
@@ -262,7 +300,7 @@ sub draw_caption
 	my ( $self, $canvas, $x, $y) = @_;
 	my ($cap, $tilde) = @{ $self-> text_wrap_shape( $self-> text, 
 		undef, 
-		options => tw::CalcMnemonic|tw::CollapseTilde|tw::ExpandTabs,
+		options => tw::CalcMnemonic|tw::CollapseTilde|tw::ExpandTabs|tw::ReturnGlyphs,
 		tabs    => 1,
 	) };
 	unless ( $self->enabled) {
@@ -295,7 +333,13 @@ sub caption_box
 	my $cap = $self-> text;
 	$cap =~ s/~//;
 	$canvas = $self unless $canvas;
-	return $canvas-> get_text_width( $cap), $canvas-> font-> height;
+	my $end_paint_info = $canvas->get_paint_state == ps::Disabled;
+	$canvas->begin_paint_info if $end_paint_info;
+	$canvas-> font-> style( $canvas-> font-> style  | fs::Bold )
+		if $self-> {default} && $self->skin eq 'flat';
+	my ( $w, $h ) = ($canvas-> get_text_width( $cap), $canvas-> font-> height);
+	$canvas->end_paint_info if $end_paint_info;
+	return ($w, $h);
 }
 
 sub calc_geom_size { $_[0]-> caption_box }
@@ -340,6 +384,23 @@ sub autoWidth
 	$self-> check_auto_size if $a;
 }
 
+sub autoShaping
+{
+	return $_[0]-> {autoShaping} unless $#_;
+	my ( $self, $a) = @_;
+	return if ( $self-> {autoShaping} ? 1 : 0) == ( $a ? 1 : 0);
+	$self-> {autoShaping} = ( $a ? 1 : 0);
+	if ( $a ) {
+		if ( $self->skin eq 'flat') {
+			$self->shape(undef);
+		} else {
+			$self->update_shape;
+		}
+	}
+}
+
+sub update_shape {}
+
 sub check_auto_size
 {
 	my $self = $_[0];
@@ -424,20 +485,12 @@ sub init
 	return %profile;
 }
 
-sub on_paint
+sub paint_classic
 {
-	my ($self,$canvas)  = @_;
-	my @clr  = ( $self-> color, $self-> backColor);
-	@clr = ( $self-> hiliteColor, $self-> hiliteBackColor)
-		if $self-> { default};
-	$clr[1] = $self-> prelight_color($clr[1]) if $self->{hilite} && $self-> enabled;
-	@clr = ( $self-> disabledColor, $self-> disabledBackColor)
-		if !$self-> enabled;
-	my @size = $canvas-> size;
-
+	my ( $self, $canvas, $w, $h, @clr) = @_;
 	my @fbar = $self-> {default} ?
-		( 1, 1, $size[0] - 2, $size[1] - 2):
-		( 0, 0, $size[0] - 1, $size[1] - 1);
+		( 1, 1, $w - 2, $h - 2):
+		( 0, 0, $w - 1, $h - 1);
 	if ( !$self-> {flat} || $self-> {hilite}) {
 		$self-> rect_bevel( $canvas, @fbar,
 			fill => $self->transparent ? undef : $self-> new_gradient(
@@ -454,11 +507,85 @@ sub on_paint
 	}
 	if ( $self-> {default}) {
 		$canvas-> color( cl::Black);
-		$canvas-> rectangle( 0, 0, $size[0]-1, $size[1]-1);
+		$canvas-> rectangle( 0, 0, $w-1, $h-1);
+	}
+}
+
+sub paint_flat
+{
+	my ( $self, $canvas, $w, $h, @clr) = @_;
+	$canvas-> graphic_context( sub {
+		$canvas-> color( $self-> owner-> backColor );
+		$canvas-> bar( 0, 0, $w, $h);
+		$canvas-> backColor( $clr[1]);
+		$canvas-> color( $clr[0]);
+		my $lw = 1;
+		$lw++ if $self->{default};
+		if ( $self->enabled ) {
+			if ( $self->{hilite}) {
+				$lw++;
+			} elsif ( defined ( my $f = $self->fader_current_value)) {
+				$lw += $f;
+			}
+		}
+		$canvas-> antialias(1);
+		my $dw;
+		if ( $canvas-> antialias ) {
+			$dw = $self->font->height;
+		} else {
+			$dw = 0;
+			$lw = int($lw + .5);
+		}
+		$canvas-> lineWidth( $lw );
+		$canvas->
+			new_path->
+			round_rect( 0 + $lw/2, 0 + $lw/2, $w - $lw/2 - 1, $h - $lw/2 - 1, $dw)->
+			fill_stroke;
+	}) unless $self-> transparent;
+}
+
+sub update_shape
+{
+	my $self = shift;
+	my @sz = $self->size;
+	my $shape = $self-> new_path-> round_rect(
+		-1.5, -1.5, $sz[0]+.5, $sz[1]+.5,
+		$self-> font-> height
+	)-> region;
+	$self->shape($shape);
+}
+
+sub on_paint
+{
+	my ($self,$canvas)  = @_;
+	my @clr  = ( $self-> color, $self-> backColor);
+	my $skin = $self->skin;
+
+	my $boldify;
+	if ($self-> { default}) {
+		if ( $skin eq 'flat') {
+			@clr = ( $self-> hiliteBackColor, $self-> hiliteColor);
+			$boldify++;
+		} else {
+			@clr = ( $self-> hiliteColor, $self-> hiliteBackColor);
+		}
+	}
+	if ( $self->enabled ) {
+		$clr[1] = $self-> fader_current_color($clr[1]);
+	} else {
+		@clr = ( $self-> disabledColor, $self-> disabledBackColor);
 	}
 
+	my @size = $canvas-> size;
+
 	my $shift  = $self-> {checked} ? 1 : 0;
+	if ( $skin eq 'flat') {
+		$self->paint_flat($canvas, @size, @clr);
+	} else {
+		$self->paint_classic($canvas, @size, @clr);
+	}
 	$shift += $self-> {pressed} ? 2 : 0;
+
 	my $capOk = length($self-> text) > 0;
 	my ( $fw, $fh) = $capOk ? $self-> caption_box($canvas) : ( 0, 0);
 	my ( $textAtX, $textAtY);
@@ -575,7 +702,11 @@ CAPTION:
 		$textAtY = ( $size[1] - $fh) / 2 - $shift;
 	}
 	$canvas-> color( $clr[0]);
-	$self-> draw_caption( $canvas, $textAtX, $textAtY) if $capOk;
+	if ($capOk) {
+		$canvas-> font-> style( $canvas-> font-> style  | fs::Bold )
+			if $boldify;
+		$self-> draw_caption( $canvas, $textAtX, $textAtY);
+	}
 	$canvas-> rect_focus( 4, 4, $size[0] - 5, $size[1] - 5 ) if !$capOk && $self-> focused;
 }
 
@@ -702,6 +833,8 @@ sub default
 	$self-> repaint;
 }
 
+sub hilite { $_[0]->{hilite} }
+
 sub defaultGlyph {($#_)?($_[0]-> {defaultGlyph} = $_[1],$_[0]-> repaint) :return $_[0]-> {defaultGlyph}}
 sub hiliteGlyph  {($#_)?($_[0]-> {hiliteGlyph}  = $_[1],$_[0]-> repaint) :return $_[0]-> {hiliteGlyph}}
 sub disabledGlyph{($#_)?($_[0]-> {disabledGlyph}= $_[1],$_[0]-> repaint) :return $_[0]-> {disabledGlyph}}
@@ -919,26 +1052,9 @@ sub profile_default
 	}
 }
 
-sub on_paint
+sub paint_classic
 {
-	my ($self,$canvas) = @_;
-	my @clr;
-	if ( $self-> enabled) {
-		if ( $self-> focused) {
-			@clr = ($self-> hiliteColor, $self-> hiliteBackColor);
-		} else {
-			@clr = ($self-> color, $self-> backColor);
-		}
-		$clr[1] = $self-> prelight_color($clr[1]) if $self->{hilite} && $self-> enabled;
-	} else {
-		@clr = ($self-> disabledColor, $self-> disabledBackColor);
-	}
-
-	my @size = $canvas-> size;
-	unless ( $self-> transparent) {
-		$canvas-> color( $clr[ 1]);
-		$canvas-> bar( 0, 0, @size);
-	}
+	my ( $self, $canvas, $w, $h, @clr) = @_;
 
 	my ( $image, $imNo);
 	if ( $self-> { checked}) {
@@ -951,20 +1067,20 @@ sub on_paint
 	my @c3d  = ( $self-> light3DColor, $self-> dark3DColor);
 
 	if ( $image) {
-		$canvas-> put_image( 0, ( $size[1] - $image-> height) / 2, $image);
+		$canvas-> put_image( 0, ( $h - $image-> height) / 2, $image);
 		$xStart = $image-> width;
 	} else {
 		my $s = $::application->uiScaling;
 		$xStart = $s * 16;
 		push ( @c3d, shift @c3d)
 			if $self-> { pressed};
-		$canvas-> rect3d( 1, ( $size[1] - $s*14) / 2, $s*15, ( $size[1] + $s*14) / 2, 1,
+		$canvas-> rect3d( 1, ( $h - $s*14) / 2, $s*15, ( $h + $s*14) / 2, 1,
 			@c3d, $clr[ 1]);
 		if ( $self-> { checked}) {
 			my $at = $self-> { pressed} ? 1 : 0;
 			$canvas-> color( cl::Black);
 			$canvas-> lineWidth( 2);
-			my $yStart = ( $size[1] - $s*14) / 2;
+			my $yStart = ( $h - $s*14) / 2;
 			$canvas-> line(
 				$at + $s*4, $yStart - $at +  $s*8,
 				$at + $s*5 , $yStart - $at + $s*3
@@ -976,6 +1092,89 @@ sub on_paint
 			$canvas-> lineWidth( 0);
 		}
 	}
+	return $xStart;
+}
+
+sub paint_flat_background
+{
+	my ( undef, $path, $height ) = @_;
+	my $s = $::application->uiScaling;
+	$path-> round_rect(
+		1,       ( $height - $s*14) / 2,
+		$s * 15, ( $height + $s*14) / 2,
+		$s * 7
+	);
+	return $s * 15;
+}
+
+sub paint_flat_checkmark
+{
+	my ( undef, $path, $height ) = @_;
+	my $s = $::application->uiScaling;
+	my $yStart = ( $height - $s*14) / 2;
+	$path-> line(
+		$s*4,  $yStart + $s*8,
+		$s*5 , $yStart + $s*3,
+		$s*5 , $yStart + $s*3,
+		$s*12, $yStart + $s*12
+	);
+}
+
+sub paint_flat
+{
+	my ( $self, $canvas, $w, $h, @clr) = @_;
+
+	my $s = $::application->uiScaling;
+	my $xStart = $s * 16;
+
+	$canvas-> graphic_context( sub {
+		$canvas-> antialias(1);
+		$canvas-> lineWidth( 1 );
+		$canvas-> color($clr[0]);
+		my $path1 = $canvas->new_path;
+		$self-> paint_flat_background( $path1, $h);
+		$path1->stroke;
+
+		if ( $self-> { checked} || $self->{ pressed } ) {
+			my $at = $self-> { pressed} ? 1 : 0;
+			$canvas-> color( $clr[0]);
+			$canvas-> lineWidth( 2);
+			$canvas-> translate( $at, -$at);
+			my $path2 = $canvas->new_path;
+			$self-> paint_flat_checkmark( $path2, $h);
+			$path2->stroke;
+		}
+	});
+	return $xStart;
+}
+
+sub on_paint
+{
+	my ($self,$canvas) = @_;
+	my @clr;
+	if ( $self-> enabled) {
+		if ( $self-> focused) {
+			@clr = ($self-> hiliteColor, $self-> hiliteBackColor);
+		} else {
+			@clr = ($self-> color, $self-> backColor);
+		}
+		$clr[1] = $self-> fader_current_color($clr[1]);
+	} else {
+		@clr = ($self-> disabledColor, $self-> disabledBackColor);
+	}
+
+	my @size = $canvas-> size;
+	unless ( $self-> transparent) {
+		$canvas-> color( $clr[ 1]);
+		$canvas-> bar( 0, 0, @size);
+	}
+
+	my $xStart;
+	if ( $self->skin eq 'flat') {
+		$xStart = $self->paint_flat( $canvas, @size, @clr);
+	} else {
+		$xStart = $self->paint_classic( $canvas, @size, @clr);
+	}
 
 	$canvas-> color( $clr[ 0]);
 	my ( $fw, $fh) = $self-> caption_box( $canvas);
@@ -994,27 +1193,9 @@ sub profile_default
 	return $def;
 }
 
-sub on_paint
+sub paint_classic
 {
-	my ($self,$canvas) = @_;
-	my @clr;
-	if ( $self-> enabled) {
-		if ( $self-> focused) {
-			@clr = ($self-> hiliteColor, $self-> hiliteBackColor);
-		} else {
-			@clr = ($self-> color, $self-> backColor);
-		}
-		$clr[1] = $self-> prelight_color($clr[1]) if $self->{hilite} && $self-> enabled;
-	} else {
-		@clr = ($self-> disabledColor, $self-> disabledBackColor);
-	}
-
-	my @size = $canvas-> size;
-	unless ( $self-> transparent) {
-		$canvas-> color( $clr[ 1]);
-		$canvas-> bar( 0, 0, @size);
-	}
-
+	my ( $self, $canvas, $w, $h, @clr) = @_;
 	my ( $image, $imNo);
 	if ( $self-> { checked}) {
 		$imNo = $self-> { pressed} ? 7 : 6;
@@ -1025,12 +1206,12 @@ sub on_paint
 	my $xStart;
 	$image = $images[ $imNo];
 	if ( $image) {
-		$canvas-> put_image( 0, ( $size[1] - $image-> height) / 2, $image);
+		$canvas-> put_image( 0, ( $h - $image-> height) / 2, $image);
 		$xStart = $image-> width;
 	} else {
 		my $s = $::application->uiScaling;
 		$xStart = $s * 16;
-		my $y = ( $size[1] - $s * 16) / 2;
+		my $y = ( $h - $s * 16) / 2;
 		my @xs = map { $s * $_ } ( 0, 8, 16, 8);
 		my @ys = map { $s * $_ } ( 8, 16, 8, 0);
 		for ( @ys) {$_+=$y};
@@ -1067,6 +1248,60 @@ sub on_paint
 			$canvas-> fillpoly( [ $s*6, $y+$s*8, $s*8, $y+$s*10, $s*10, $y+$s*8, $s*8, $y+$s*6]);
 		}
 	}
+}
+
+sub paint_flat
+{
+	my ( $self, $canvas, $w, $h, @clr) = @_;
+
+	my $s = $::application->uiScaling;
+	my $xStart = $s * 16;
+
+	$canvas-> graphic_context( sub {
+		$canvas-> antialias(1);
+		$canvas-> lineWidth( 1 );
+		$canvas-> color($clr[0]);
+
+		my $center = $h / 2;
+		my $x = 1 + $s * 7.5;
+		$canvas-> ellipse( $x, $center, $s * 15, $s * 15);
+
+		if ( $self-> { checked} || $self->{ pressed } ) {
+			my $at = $self-> {pressed} ? 1 : 0;
+			$canvas-> fill_ellipse( $x + $at, $center - $at, $s * 8, $s * 8);
+		}
+	});
+	return $xStart;
+}
+
+sub on_paint
+{
+	my ($self,$canvas) = @_;
+	my @clr;
+	if ( $self-> enabled) {
+		if ( $self-> focused) {
+			@clr = ($self-> hiliteColor, $self-> hiliteBackColor);
+		} else {
+			@clr = ($self-> color, $self-> backColor);
+		}
+		$clr[1] = $self-> fader_current_color($clr[1]);
+	} else {
+		@clr = ($self-> disabledColor, $self-> disabledBackColor);
+	}
+
+	my @size = $canvas-> size;
+	unless ( $self-> transparent) {
+		$canvas-> color( $clr[ 1]);
+		$canvas-> bar( 0, 0, @size);
+	}
+
+	my $xStart;
+	if ( $self->skin eq 'flat') {
+		$xStart = $self->paint_flat( $canvas, @size, @clr);
+	} else {
+		$xStart = $self->paint_classic( $canvas, @size, @clr);
+	}
+
 	$canvas-> color( $clr[ 0]);
 	my ( $fw, $fh) = $self-> caption_box( $canvas);
 	$self-> draw_caption( $canvas, $xStart * 1.5, ( $size[1] - $fh) / 2 );
@@ -1137,11 +1372,27 @@ sub profile_default
 {
 	return {
 		%{$_[ 0]-> SUPER::profile_default},
+		border             => 1,
 		ownerBackColor     => 1,
 		autoEnableChildren => 1,
 	}
 }
 
+sub init
+{
+	my $self = shift;
+	my %profile = $self-> SUPER::init(@_);
+	$self-> {border}  = $profile{border};
+	return %profile;
+}
+
+sub border
+{
+	return $_[0]->{border} unless $#_;
+	$_[0]->{border} = $_[1];
+	$_[0]->repaint;
+}
+
 sub on_radioclick
 {
 	my ($me,$rd) = @_;
@@ -1164,10 +1415,17 @@ sub on_paint
 		$canvas-> bar( 0, 0, @size);
 	}
 	my $fh = $canvas-> font-> height;
-	$canvas-> color( $self-> light3DColor);
-	$canvas-> rectangle( 1, 0, $size[0] - 1, $size[1] - $fh / 2 - 2);
-	$canvas-> color( $self-> dark3DColor);
-	$canvas-> rectangle( 0, 1, $size[0] - 2, $size[1] - $fh / 2 - 1);
+	if ( $self->{border}) {
+		if ( $self->skin eq 'flat') {
+			$canvas-> color( $self-> dark3DColor);
+			$canvas-> rectangle( 0, 0, $size[0] - 1, $size[1] - $fh / 2 - 1);
+		} else {
+			$canvas-> color( $self-> light3DColor);
+			$canvas-> rectangle( 1, 0, $size[0] - 1, $size[1] - $fh / 2 - 2);
+			$canvas-> color( $self-> dark3DColor);
+			$canvas-> rectangle( 0, 1, $size[0] - 2, $size[1] - $fh / 2 - 1);
+		}
+	}
 	my $c = $self->text;
 	if ( length( $c) > 0) {
 		$c = $self-> text_shape($c, skip_if_simple => 1) || $c;
@@ -1346,7 +1604,8 @@ Called whenever the user presses the button.
 
 =item hotKey CHAR
 
-A key that the button will react to if pressed, even when out of focus.
+A key (defined by CHAR) that the button will react to if pressed, if the button has the focus
+The combination ALT + Key works always if the button has the focus or not
 
 =item pressed BOOLEAN
 
@@ -1412,6 +1671,16 @@ released. Useful for emulating the marginal scroll-bar buttons.
 
 Default value: 0
 
+=item autoShaping BOOLEAN
+
+If 1, the button C<shape> is autmatically update when the button size and/or
+font are updated, if the current skin can make use of non-rectangular shapes.
+Generally is unneeded unless the owner of the button has a different back color
+or features some custom painting.
+
+Default value: 0
+
+See also: F<examples/triangle.pl>, F<examples/dragdrop.pl>
 
 =item autoWidth BOOLEAN
 
@@ -1420,7 +1689,6 @@ change.
 
 Default value: 1
 
-
 =item borderWidth INTEGER
 
 Width of 3d-shade border around the button.
@@ -1486,7 +1754,11 @@ L<hiliteGlyph>, L<disabledGlyph>, L<pressedGlyph>, L<holdGlyph>.
 
 Default value: 1
 
-=item hiliteGlyph INTEGE | IMAGE | METAFILER
+=item hilite
+
+Read-only property, return 1 if the button is highlighted, 0 otherwise.
+
+=item hiliteGlyph INTEGER | IMAGE | METAFILER
 
 Selects index of the sub-image for the state when the mouse pointer is
 over the button. This image is used only when L<flat> property is set.
@@ -1691,6 +1963,10 @@ to disable this functionality.
 
 =over
 
+=item border BOOLEAN
+
+If set (default), draws a border along the widget boundaries
+
 =item index INTEGER
 
 Checks the child radio button with C<index>. The indexing is
