@@ -211,8 +211,12 @@ sub Day_Paint
 	my @sz = $self-> size;
 	$canvas-> set( color => $self-> disabledColor, backColor => $self-> disabledBackColor)
 		unless $self-> enabled;
-	$canvas-> rect3d( Prima::rect->new(@sz)->inclusive, 2,
-		$self-> dark3DColor, $self-> light3DColor, $self-> backColor);
+	if ( $owner-> skin eq 'flat') {
+		$canvas-> clear( Prima::rect->new(@sz)->inclusive );
+	} else {
+		$canvas-> rect3d( Prima::rect->new(@sz)->inclusive, 2,
+			$self-> dark3DColor, $self-> light3DColor, $self-> backColor);
+	}
 
 	my @zs = ( $self-> {X}, $self-> {Y}, $self-> {CX1}, $self-> {CY});
 	my $i;
@@ -222,9 +226,10 @@ sub Day_Paint
 	$canvas-> color($c);
 	$canvas-> clipRect( Prima::rect->new(@sz)->shrink(2)->inclusive );
 	my $fdo = $owner-> firstDayOfWeek ? 6 : 0;
+	my $sunday = (cl::distance( $canvas->backColor, cl::Black) > 200) ? 0xc00000 : 0xff0000;
 	for ( $i = 0; $i < 7; $i++) {
 		my $tw = $canvas->get_text_width( $owner-> {days}-> [$i] );
-		$canvas-> color( 0xc00000 ) if $i == $fdo;
+		$canvas-> color( $sunday ) if $i == $fdo;
 		$canvas-> text_shape_out( $owner-> {days}-> [$i],
 			$i * $zs[0] + ($self->{X} - $tw)/2, $sz[1]-$zs[1]+$zs[3],
 		);
@@ -247,7 +252,7 @@ sub Day_Paint
 				( 1 + $dow) * $zs[0] - 1, $y - $zs[3] + $zs[1] - 1
 			);
 			$canvas-> color(( $d == $i) ? cl::HiliteText : cl::Fore);
-			$canvas-> color( 0xc00000 ) if $d != $i && $dow == $fdo;
+			$canvas-> color( $sunday ) if $d != $i && $dow == $fdo;
 			$canvas-> text_shape_out( $i + 1, $dow * $zs[0] + $zs[2], $y);
 			$canvas-> rect_focus(
 				$dow * $zs[0] + 2, $y - $zs[3],
@@ -255,7 +260,7 @@ sub Day_Paint
 			) if $d == $i && $self-> focused;
 			$canvas-> color( $c);
 		} else {
-			$canvas-> color( 0xc00000 ) if $dow == $fdo;
+			$canvas-> color( $sunday ) if $dow == $fdo;
 			$canvas-> text_shape_out( $i + 1, $dow * $zs[0] + $zs[2], $y);
 			$canvas-> color( $c ) if $dow == $fdo;
 		}
