@@ -104,6 +104,28 @@ sub STORESIZE {
 }
 sub DELETE    { warn "This array does not implement delete functionality" }
 sub PUSH      { $_[0]->[REF] .= pack( $_[0]->[PACK] . '*', @_[1..$#_] ) if $#_ }
+sub POP       { length($_[0]->[REF]) ? unpack( $_[0]->[PACK], CORE::substr( $_[0]->[REF], -$_[0]->[SIZE], $_[0]->[SIZE], '' )) : undef }
+sub SHIFT     { length($_[0]->[REF]) ? unpack( $_[0]->[PACK], CORE::substr( $_[0]->[REF], 0, $_[0]->[SIZE], '' )) : undef }
+sub UNSHIFT   { CORE::substr( $_[0]->[REF], 0, 0, pack( $_[0]->[PACK] . '*', @_[1..$#_] )) if $#_ }
+sub CLEAR     { CORE::substr( $_[0]->[REF], 0 ) = '' }
+
+sub SPLICE
+{
+	# thanks to Dan Kogai and his Tie::Array::Pack for this code
+	my $self      = shift;
+	my $offset    = @_ ? shift() : 0;
+	my $unit_size = $self->[SIZE];
+	my $arr_len   = length( $self->[REF] ) / $unit_size;
+	$offset += $arr_len if $offset < 0;
+	my $length = @_ ? shift() : ($arr_len - $offset);
+	$length += $arr_len - $offset if $length < 0;
+	my @result = unpack(
+		$self->[PACK] . $length,
+		CORE::substr( $self->[REF], $offset * $unit_size, $length * $unit_size )
+	);
+	CORE::substr( $self->[REF], $offset * $unit_size, $length * $unit_size, pack( $self->[PACK] x @_, @_ )) if @_;
+	return wantarray ? @result : pop @result;
+}
 
 package Prima::rect;
 
@@ -930,6 +952,20 @@ sub to_rgba
 	return $i;
 }
 
+sub to_colormask
+{
+	my ( $self, $color ) = @_;
+	my $icon = Prima::Icon->new(
+		size      => [ $self-> size ],
+		type      => im::RGB,
+		backColor => $color,
+		mask      => $self,
+	);
+	$icon-> clear;
+	$icon-> premultiply_alpha;
+	return $icon;
+}
+
 sub load_stream
 {
 	shift;
@@ -969,8 +1005,18 @@ sub profile_check_in
 {
 	my ( $self, $p, $default) = @_;
 
-	if ( exists $p-> {mask} and not exists $p-> {autoMasking}) {
-		$p-> {autoMasking} = am::None;
+	if ( exists $p-> {mask} ) {
+		$p-> {autoMasking} = am::None if not exists $p-> {autoMasking};
+		if (ref($p->{mask}) && UNIVERSAL::isa($p->{mask}, 'Prima::Image')) {
+			my $i = $p->{mask};
+			my $newbpp = ($i->get_bpp == 1) ? 1 : 8;
+			if ( exists $p->{maskType} && $p->{maskType} != $newbpp ) {
+				$p->{mask} = $i->clone( type => $newbpp )->data;
+			} else {
+				$p->{maskType} = $newbpp;
+			}
+		}
+
 	}
 	$self-> SUPER::profile_check_in( $p, $default);
 }
@@ -2240,6 +2286,8 @@ sub on_change
 	for (0,1) {
 		$sz[$_] = $as[$_] if $sz[$_] > $as[0];
 	}
+	$sz[0] += $self->font->width * 2;
+	$sz[1] += $self->font->height;
 	$self-> size(@sz);
 }
 
@@ -2251,7 +2299,9 @@ sub on_paint
 	$canvas-> rectangle( 0, 0, $size[0]-1, $size[1]-1);
 
 	my @ln = $canvas->text_split_lines($self->text) or return;
-	my ($x, $y, $fh) = ( 3, $size[1] - 1, $self->font->height);
+	my ($x, $y, $fh, $fw) = ( 3, $size[1] - 1, $self->font->height, $self->font->width);
+	$x += $fw;
+	$y -= $fh / 2;
 	for my $t (@ln) {
 		$y -= ref($t) ? $t->height($canvas) : $fh;
 		$canvas-> text_shape_out( $t, $x, $y);
