@@ -8,6 +8,19 @@ use constant DropDownList =>  2;
 use strict;
 use warnings;
 
+package Prima::ComboBox::Button;
+use base qw(Prima::Widget Prima::Widget::Fader);
+
+{
+my %RNT = (
+	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
+	Check => nt::Default,
+);
+
+sub notification_types { return \%RNT; }
+}
+
 package Prima::ComboBox;
 
 use vars qw(@ISA %listProps %editProps %listDynas $capture_mode);
@@ -77,7 +90,7 @@ sub profile_default
 
 		editClass      => 'Prima::InputLine',
 		listClass      => 'Prima::ListBox',
-		buttonClass    => 'Prima::Widget',
+		buttonClass    => 'Prima::ComboBox::Button',
 		scrollBarClass => 'Prima::ScrollBar',
 		editProfile    => {},
 		listProfile    => {},
@@ -87,7 +100,7 @@ sub profile_default
 		listDelegations   => [qw(Leave SelectItem MouseUp Click KeyDown Paint)],
 		editDelegations   => [qw(FontChanged Create Setup KeyDown KeyUp Change Leave MouseWheel MouseDown)],
 		buttonDelegations => [qw(ColorChanged FontChanged MouseDown MouseClick
-			MouseUp MouseMove MouseEnter MouseLeave Paint Enable Disable)],
+			MouseUp MouseMove MouseEnter MouseLeave Paint Enable Disable FadeOut)],
 	}
 }
 
@@ -324,21 +337,22 @@ sub Button_MouseEnter
 {
 	my ( $self, $button ) = @_;
 	if ( !$button->capture && $self->enabled) {
+		$button-> fader_in_mouse_enter;
 		$button->{prelight} = 1;
-		$button->repaint;
 	}
 }
 
 sub Button_MouseLeave
 {
 	my ( $self, $button ) = @_;
-	if ( !$button->capture && $button->{prelight}) {
-		delete $button->{prelight};
-		$button->repaint;
+	if ( !$button->capture && $self->enabled) {
+		$button-> fader_out_mouse_leave;
 	}
 
 }
 
+sub Button_FadeOut { delete $_[1]->{prelight} }
+
 sub Button_MouseUp { $_[1]-> capture(0); }
 
 sub fix_triangle
@@ -376,10 +390,13 @@ sub Button_Paint
 		$canvas-> graphic_context( sub {
 			$canvas-> color( $self-> dark3DColor ); 
 			$canvas-> rectangle(-1, 0, $w-1, $h-1); # yes, -1
+			my $pct = 0.33;
+			$pct *= 1 + ( $self-> fader_current_value // 1 )
+				if $self->{prelight};
 			my $c = cl::blend(
-				$self->map_color( $hbc ),
 				$self->map_color( $clr[1] ),
-				$self->{prelight} ? 0.33 : 0.66
+				$self->map_color( $hbc ),
+				$pct
 			);
 			$canvas-> color( $c );
 			$canvas-> bar( 1 - 1, 1, $w-2, $h-2);
@@ -387,7 +404,7 @@ sub Button_Paint
 		$clr[0] = $self->hiliteColor;
 		$canvas-> translate(1,-1) if $lv;
 	} else {
-		$clr[1] = $self->prelight_color($clr[1]) if $self->{prelight};
+		$clr[1] = $self->fader_prelight_color($clr[1]) if $self->{prelight};
 		$self-> rect_bevel(
 			$canvas, 0, 0, $w-1, $h-1,
 			fill => $self-> new_gradient(
