@@ -40,6 +40,75 @@ sub rect3d
 	$self-> color( $c);
 }
 
+sub rect_solid
+{
+	my ( $canvas, $x1, $y1, $x2, $y2, $lw, $fg) = @_;
+	($x1, $x2) = ($x2, $x1) if $x2 < $x1;
+	($y1, $y2) = ($y2, $y1) if $y2 < $y1;
+	$lw //= 1;
+	return if $lw < 1;
+	$canvas-> graphic_context( sub {
+		$canvas->antialias(0);
+		$canvas->fillPattern(fp::Solid);
+		$canvas-> color( $fg ) if defined $fg;
+		if ( $x1 + $lw * 2 > $x2 || $y1 + $lw * 2 > $y2 ) {
+			$canvas-> bar( $x1, $y1, $x2, $y2 );
+		} elsif ( $lw == 1 ) {
+			$canvas-> lineWidth(0);
+			$canvas-> linePattern(lp::Solid);
+			$canvas-> rectangle( $x1, $y1, $x2, $y2);
+		} else {
+			$lw--;
+			$canvas-> bars([
+				$x1, $y1, $x1 + $lw, $y2,
+				$x2 - $lw, $y1, $x2, $y2,
+				$x1 + $lw + 1, $y1, $x2 - $lw - 1, $y1 + $lw,
+				$x1 + $lw + 1, $y2 - $lw, $x2 - $lw - 1, $y2
+			]);
+		}
+	});
+}
+
+sub rect_fill
+{
+	my ( $canvas, $x1, $y1, $x2, $y2, $lw, $fg, $bg) = @_;
+	($x1, $x2) = ($x2, $x1) if $x2 < $x1;
+	($y1, $y2) = ($y2, $y1) if $y2 < $y1;
+	$lw //= 1;
+	$canvas-> graphic_context( sub {
+		$canvas->antialias(0);
+		if ( $lw <= 0 ) {
+			$canvas-> color( $bg ) if defined $bg;
+			$canvas-> fillPattern(fp::Solid);
+			$canvas-> bar( $x1, $y1, $x2, $y2 );
+		} elsif ( $x1 + $lw * 2 > $x2 || $y1 + $lw * 2 > $y2 ) {
+			$canvas-> color( $fg ) if defined $fg;
+			$canvas-> bar( $x1, $y1, $x2, $y2 );
+		} elsif ( $lw == 1 ) {
+			$bg //= $canvas->backColor;
+			$canvas-> color( $fg ) if defined $fg;
+			$canvas-> lineWidth(0);
+			$canvas-> linePattern(lp::Solid);
+			$canvas-> rectangle( $x1, $y1, $x2, $y2);
+			$canvas-> color( $bg );
+			$canvas-> bar( $x1 + 1, $y1 + 1, $x2 - 1, $y2 - 1);
+		} else {
+			$fg //= $canvas->color;
+			$canvas-> color( $bg ) if defined $bg;
+			$canvas-> bar( $x1 + $lw, $y1 + $lw, $x2 - $lw, $y2 - $lw);
+			$lw--;
+			$canvas-> color( $fg );
+			$canvas-> fillPattern(fp::Solid);
+			$canvas-> bars([
+				$x1, $y1, $x1 + $lw, $y2,
+				$x2 - $lw, $y1, $x2, $y2,
+				$x1 + $lw + 1, $y1, $x2 - $lw - 1, $y1 + $lw,
+				$x1 + $lw + 1, $y2 - $lw, $x2 - $lw - 1, $y2
+			]);
+		}
+	});
+}
+
 sub rect_focus
 {
 	my ( $canvas, $x, $y, $x1, $y1, $width) = @_;
@@ -51,6 +120,7 @@ sub rect_focus
 	return unless $canvas-> graphic_context_push;
 	$canvas-> set(
 		fillPattern => fp::SimpleDots,
+		rop2        => rop::CopyPut,
 		color       => cl::White,
 		backColor   => cl::Black,
 		antialias   => 0,
@@ -61,10 +131,12 @@ sub rect_focus
 		$canvas-> bar( $x, $y, $x1, $y1);
 	} else {
 		$width -= 1;
-		$canvas-> bar( $x, $y, $x1, $y + $width);
-		$canvas-> bar( $x, $y1 - $width, $x1, $y1);
-		$canvas-> bar( $x, $y + $width + 1, $x + $width, $y1 - $width - 1);
-		$canvas-> bar( $x1 - $width, $y + $width + 1, $x1, $y1 - $width - 1);
+		$canvas-> bars([
+			$x, $y, $x1, $y + $width,
+			$x, $y1 - $width, $x1, $y1,
+			$x, $y + $width + 1, $x + $width, $y1 - $width - 1,
+			$x1 - $width, $y + $width + 1, $x1, $y1 - $width - 1
+		]);
 	}
 
 	$canvas-> graphic_context_pop;
@@ -168,10 +240,18 @@ sub draw_text
 			$xx = $x2 - $canvas-> get_text_width( $lines[ $tl]);
 		}
 		$tl++;
-		$canvas-> line(
-			$xx + $tildes-> {tildeStart}, $starty - $fh * $tl,
-			$xx + $tildes-> {tildeEnd}  , $starty - $fh * $tl
-		);
+		my $lw = $canvas->font->height / 20;
+		$lw = 1.0 if $lw < 1.0;
+		if ( $canvas->graphic_context_push ) {
+			$canvas->lineWidth($lw);
+			$canvas->linePattern(lp::Solid);
+			$canvas->lineEnd(le::Square);
+			$canvas-> line(
+				$xx + $tildes-> {tildeStart}, $starty - $fh * $tl,
+				$xx + $tildes-> {tildeEnd}  , $starty - $fh * $tl
+			);
+			$canvas->graphic_context_pop;
+		}
 	}
 
 	$canvas-> clipRect( @clipSave) if $flags & dt::UseClip;
@@ -185,7 +265,12 @@ sub prelight_color
 	$coeff //= 1.05;
 	return 0 if $coeff <= 0;
 	$color = $self->map_color($color) if $color & cl::SysFlag;
-	if (( $color == 0xffffff && $coeff > 1) || ($color == 0 && $coeff < 1)) {
+	my $blend = cl::blend( $color, $self->map_color($self->hiliteBackColor), 0.25 );
+	return $blend if cl::distance( $blend, $color ) > 30;
+	if (
+		((cl::distance(cl::White, $color) < 30) && $coeff > 1) ||
+		((cl::distance(cl::Black, $color) < 30) && $coeff < 1)
+	) {
 		$coeff = 1/$coeff;
 	}
 	$coeff = ($coeff - 1) * 256;
@@ -240,7 +325,7 @@ sub stroke_img_primitive
 	return 1 if $self->linePattern eq lp::Null && $self->rop2 == rop::NoOper;
 
 	my $path = $self->new_path;
-	my $matrix = $self-> matrix;
+	my $matrix = $self-> get_matrix;
 	$path->matrix( $matrix );
 	$path->$request(@_);
 	my $ok = 1;
@@ -248,7 +333,7 @@ sub stroke_img_primitive
 	return $self->graphic_context( sub {
 		# paths produce floating point coordinates and line end arcs,
 		# here we need internal pixel-wise plotting
-		$self-> matrix( $Prima::matrix::identity );
+		$self-> set_matrix( $Prima::matrix::identity );
 		$self-> lineWidth(0);
 		return $path->stroke;
 	}) if $self->lineWidth < 1.5;
@@ -270,7 +355,7 @@ sub stroke_img_primitive
 
 	return unless $self->graphic_context_push;
 	$self->fillPattern(fp::Solid);
-	$self->matrix( $Prima::matrix::identity );
+	$self->set_matrix( $Prima::matrix::identity );
 	if ( $self-> rop2 == rop::CopyPut && $self->linePattern ne lp::Solid && $self->linePattern ne lp::Null ) {
 		$self->color($self->backColor);
 		my $path3 = $path->widen( linePattern => lp::Solid );
@@ -294,7 +379,7 @@ sub fill_img_primitive
 
 	return unless $self->graphic_context_push;
 	my $path = $self->new_path;
-	$path->matrix( $self->matrix);
+	$path->matrix( $self->get_matrix);
 	$path->$request(@p);
 
 	my $region1 = $path->region( $self-> fillMode);
@@ -304,7 +389,7 @@ sub fill_img_primitive
 	$box[$_+2] += $box[$_] for 0,1;
 	$self->region($region1);
 
-	$self->matrix($Prima::matrix::identity);
+	$self->set_matrix($Prima::matrix::identity);
 	my $ok = $self->bar(@box);
 
 	$self->graphic_context_pop;
@@ -323,7 +408,7 @@ sub stroke_imgaa_primitive
 	return 0 unless $aa->can_aa;
 
 	my $path = $self->new_path;
-	$path->matrix( $self-> matrix );
+	$path->set_matrix( $self-> matrix );
 	$path->$request(@_);
 	$path = $path->widen(
 		linePattern => ( $lp eq lp::Null) ? lp::Solid : $lp
@@ -332,7 +417,7 @@ sub stroke_imgaa_primitive
 	return unless $self->graphic_context_push;
 	$self->fillPattern(fp::Solid);
 	$self->fillMode(fm::Winding | fm::Overlay);
-	$self->matrix($Prima::matrix::identity);
+	$self->set_matrix($Prima::matrix::identity);
 	$self->color($self->backColor) if $lp eq lp::Null;
 	my $ok = 1;
 	for ($path->points(fill => 1)) {
@@ -352,7 +437,7 @@ sub fill_imgaa_primitive
 
 	my $ok = 1;
 	my $path = $self->new_path;
-	my $m = $self->matrix;
+	my $m = $self->get_matrix;
 	$path->matrix($m);
 	$path->$request(@_);
 	$self->matrix($Prima::matrix::identity);
@@ -361,7 +446,7 @@ sub fill_imgaa_primitive
 		$ok = 0;
 		last;
 	}
-	$self->matrix($Prima::matrix::identity);
+	$self->set_matrix($Prima::matrix::identity);
 	return $ok;
 }
 
@@ -373,10 +458,12 @@ sub stroke_primitive
 	return 1 if $lp eq lp::Null && $self->rop2 == rop::NoOper;
 
 	my $path = $self->new_path;
+	$path->matrix( $self-> matrix );
 	$path->$request(@_);
 
 	return $self->graphic_context( sub {
 		$self-> lineWidth(0);
+		$self-> matrix-> identity;
 		return $path->stroke;
 	} ) if !$self->antialias && $self->alpha == 255 && $self->lineWidth < 1.5;
 
@@ -385,6 +472,7 @@ sub stroke_primitive
 		(!$self->antialias && $self->lineWidth == 0) ? (lineWidth => 1) : (),
 	);
 	return unless $self->graphic_context_push;
+	$self-> matrix-> identity;
 	$self->fillPattern(fp::Solid);
 	$self->fillMode(fm::Winding | fm::Overlay);
 	$self->color($self->backColor) if $lp eq lp::Null;
@@ -397,11 +485,19 @@ sub fill_primitive
 {
 	my ( $self, $request ) = (shift, shift);
 	my $path = $self->new_path;
+
+	return unless $self->graphic_context_push;
+	my $ok = 1;
+	$path->matrix( $self-> matrix );
 	$path->$request(@_);
+	$self-> matrix-> identity;
 	for ($path->points(fill => 1)) {
-		return 0 unless $self->fillpoly($_);
+		next if $self->fillpoly($_);
+		$ok = 0;
+		last;
 	}
-	return 1;
+	$self->graphic_context_pop;
+	return $ok;
 }
 
 sub text_shape_out
@@ -527,8 +623,8 @@ sub render_pattern
 		autoMasking => am::None,
 	);
 
-	if ( $opt{color}) {
-		$target->backColor($opt{color}) if $opt{color};
+	if ( defined $opt{color}) {
+		$target->backColor($opt{color});
 		$target->clear;
 	}
 	if ( exists $opt{alpha} && $handle->isa('Prima::Icon')) {
@@ -629,7 +725,7 @@ sub render_pattern
 
 Prima::Drawable::Basic
 
-=head1 NAME
+=head1 DESCRIPTION
 
 Basic drawing routines for Prima::Drawable
 
