@@ -249,7 +249,11 @@ sub arc
 	@_ > 5 or Carp::croak('bad parameters to arc');
 	my ( $cx, $cy, $dx, $dy, $from, $to, $tilt) = @_;
 	return $self if $from == $to;
-	$dx--, $dy-- unless $self->{subpixel};
+	unless ($self->{subpixel}) {
+		$dx--;
+		$dy--;
+		return $self if $dx <= 0 || $dy <= 0;
+	}
 	if ( $tilt // 0.0 ) {
 		return $self-> save->
 			scale( $dx / 2, $dy / 2)->
@@ -271,7 +275,11 @@ sub rarc
 	@_ > 3 or Carp::croak('bad parameters to arcto');
 	my ( $dx, $dy, $from, $to, $tilt) = @_;
 	return $self if $from == $to;
-	$dx--, $dy-- unless $self->{subpixel};
+	unless ($self->{subpixel}) {
+		$dx--;
+		$dy--;
+		return $self if $dx <= 0 || $dy <= 0;
+	}
 	$self->save;
 	$self->scale( $dx / 2, $dy / 2);
 	$self->rotate( $tilt // 0.0);
@@ -285,7 +293,11 @@ sub ellipse
 	@_ > 2 or Carp::croak('bad parameters to ellipse');
 	my ( $cx, $cy, $dx, $dy, $tilt) = @_;
 	$dy //= $dx;
-	$dx--, $dy-- unless $self->{subpixel};
+	unless ($self->{subpixel}) {
+		$dx--;
+		$dy--;
+		return $self if $dx <= 0 || $dy <= 0;
+	}
 	$self-> save->
 		matrix( $dx / 2, 0, 0, $dy / 2, $cx, $cy )->
 		rotate( $tilt // 0.0)->
@@ -298,7 +310,11 @@ sub chord
 	my $self = shift;
 	@_ == 6 or Carp::croak('bad parameters to chord');
 	my ( $cx, $cy, $dx, $dy, $start, $end) = @_;
-	$dx--, $dy-- unless $self->{subpixel};
+	unless ($self->{subpixel}) {
+		$dx--;
+		$dy--;
+		return $self if $dx <= 0 || $dy <= 0;
+	}
 	$self-> save->
 		matrix( $dx / 2, 0, 0, $dy / 2, $cx, $cy )->
 		circular_arc( $start, $end )->
@@ -330,7 +346,11 @@ sub sector
 	my $self = shift;
 	@_ == 6 or Carp::croak('bad parameters to sector');
 	my ( $cx, $cy, $dx, $dy, $start, $end) = @_;
-	$dx--, $dy-- unless $self->{subpixel};
+	unless ($self->{subpixel}) {
+		$dx--;
+		$dy--;
+		return $self if $dx <= 0 || $dy <= 0;
+	}
 	$self-> save->
 		matrix( $dx / 2, 0, 0, $dy / 2, $cx, $cy )->
 		line(0,0)->
@@ -342,6 +362,8 @@ sub sector
 sub round_rect
 {
 	my ( $self, $x, $y, $x1, $y1, $maxd) = @_;
+	return $self->rectangle($x, $y, $x1, $y1) if $maxd <= 0;
+
 	( $x1, $x) = ( $x, $x1) if $x > $x1;
 	( $y1, $y) = ( $y, $y1) if $y > $y1;
 	my ( $dx, $dy) = ( $x1 - $x, $y1 - $y);
@@ -378,40 +400,77 @@ sub round_rect
 
 sub new_array { shift->{subpixel} ? Prima::array->new_double : Prima::array->new_int }
 
+sub new_contour
+{
+	my $self = shift;
+	my $p = $self->{points};
+	while (@$p && @{$p->[-1]} < 4) {
+		$self->{hint_map}->[ $#$p ] = undef
+			if exists $self->{hint_map};
+		pop @$p;
+	}
+	push @$p, $self->new_array;
+}
+
 sub points
 {
 	my ($self, %opt) = @_;
+
+	my ($with_hints, $hints);
+	if ( $opt{hints}) {
+		delete $self->{points};
+		$with_hints = 1;
+	}
+
 	unless ( $self->{points} ) {
 		local $self->{stack} = [];
 		local $self->{curr}  = {
 			matrix => [ identity ],
 			( map { $_, $self->{$_} } qw(precision) )
 		};
-		$self->{points} = [[ $self->new_array ]];
+		my $p = $self->{points} = [ $self->new_array ];
+
+		my ( $lj_signal, $lj_override ) = (0,0);
 		my $c = $self->{commands};
+		$hints = $self->{hint_map} = [] if $with_hints;
+
 		for ( my $i = 0; $i < @$c; ) {
+
 			my ($cmd,$len) = @$c[$i,$i+1];
+
+			my ($np, $got_hint);
+			if ( $with_hints ) {
+				if ( $cmd eq 'spline' || $cmd eq 'arc') {
+					$lj_signal = 1;
+				} elsif ( $cmd eq 'line') {
+					$lj_signal = 0;
+				}
+				if ( $lj_signal != $lj_override ) {
+					push @{ $hints->[$#$p] }, scalar(@{$p->[-1]}) / 2;
+					$lj_override = $lj_signal;
+					$got_hint = 1;
+				}
+				$np = @$p;
+			}
+
 			$self-> can("_$cmd")-> ( $self, @$c[$i+2..$i+$len+1] );
 			$i += $len + 2;
+
+			$lj_signal = $lj_override = $got_hint = 0 if $with_hints &&
+				( $np != @$p || ($got_hint && !defined( $hints->[$#$p] )));
 		}
-		for my $ppp ( @{$self->{points}}) {
-			@$ppp = grep { @$_ > 2 } @$ppp;
-			Prima::array::deduplicate($_,2,4) for @$ppp;
-		}
+		$self-> new_contour;
+		pop @$p;
+
 		$self->{last_matrix} = $self->{curr}->{matrix};
 	}
 
-	if ( $opt{fill} ) {
-		my @ret;
-		for my $ppp ( @{ $self->points } ) {
-			my $arr = $self->new_array;
-			Prima::array::append( $arr, $_ ) for @$ppp;
-			push @ret, $arr if @$arr > 2;
-		}
-		return @ret;
+	if ( $opt{hints}) {
+		delete $self->{hint_map};
+		return $self->{points}, $hints;
 	}
 
-	return $self->{points};
+	return wantarray ? @{$self->{points}} : $self->{points};
 }
 
 sub last_matrix
@@ -424,9 +483,7 @@ sub last_matrix
 sub last_point
 {
 	for ( reverse @{ shift->{points} }) {
-		for ( reverse @$_ ) {
-			return $$_[-2], $$_[-1] if @$_;
-		}
+		return $$_[-2], $$_[-1] if @$_;
 	}
 	return 0,0;
 }
@@ -494,44 +551,45 @@ sub  _moveto
 	my ( $self, $mx, $my, $rel) = @_;
 	($mx, $my) = $self->matrix_apply($mx, $my);
 	my ($lx, $ly) = $rel ? $self->last_point : (0,0);
-	my $arr = $self->new_array;
-	push @$arr, $self->{subpixel} ? ($lx + $mx, $ly + $my) : Prima::Utils::nearest_i($lx + $mx, $ly + $my);
-	push @{$self->{points}->[-1]}, $arr;
+	push @{$self->{points}->[-1]},
+		$self->{subpixel} ?
+			($lx + $mx, $ly + $my) :
+			Prima::Utils::nearest_i($lx + $mx, $ly + $my);
 }
 
-sub _open { push @{$_[0]->{points}}, [$_[0]->new_array] }
+sub _open { shift-> new_contour }
 
 sub _close
 {
 	my $self = shift;
 	my $p = $self->{points};
 	return unless @$p;
-	my $l = $p->[-1]->[-1];
+	my $l = $p->[-1];
 	push @$l, $$l[0], $$l[1] if @$l && ($$l[0] != $$l[-2] || $$l[1] != $$l[-1]);
-	push @$p, [$self->new_array];
+	$self-> new_contour;
 }
 
 sub _line
 {
 	my ( $self, $line ) = @_;
-	Prima::array::append( $self->{points}->[-1]->[-1],
-		Prima::Drawable->render_polyline( $line,
-			matrix  => $self->{curr}->{matrix},
-			integer => !$self->{subpixel},
-		)
+	my $ppp = Prima::Drawable->render_polyline( $line,
+		matrix  => $self->{curr}->{matrix},
+		integer => !$self->{subpixel},
 	);
+	Prima::array::deduplicate($ppp,2,4);
+	Prima::array::append( $self->{points}->[-1], $ppp);
 }
 
 sub _spline
 {
 	my ( $self, $points, $options ) = @_;
-	Prima::array::append( $self->{points}->[-1]->[-1],
-		Prima::Drawable->render_spline(
-			$self-> matrix_apply( $points ),
-			%$options,
-			integer => !$self->{subpixel},
-		)
+	my $ppp = Prima::Drawable->render_spline(
+		$self-> matrix_apply( $points ),
+		%$options,
+		integer => !$self->{subpixel},
 	);
+	Prima::array::deduplicate($ppp,2,4);
+	Prima::array::append( $self->{points}->[-1], $ppp);
 }
 
 # Reference:
@@ -607,7 +665,7 @@ sub _arc
 
 	my %xopt;
 	$xopt{precision} = $self->{curr}->{precision} // 24;
-	$xopt{precision} = $scaling if $xopt{precision} // 24 > $scaling;
+	$xopt{precision} = $scaling if $xopt{precision} > $scaling;
 	$xopt{integer}   = !$self->{subpixel};
 	$xopt{precision} *= 2 if
 		$self->{subpixel} &&
@@ -624,14 +682,15 @@ sub _arc
 		} elsif ($xopt{precision} >= 2) {
 			$poly = Prima::Drawable->render_spline( $poly, @options, %xopt);
 		}
-		Prima::array::append( $self->{points}->[-1]->[-1], $poly);
+		Prima::array::deduplicate($poly,2,4);
+		Prima::array::append( $self->{points}->[-1], $poly);
 	}
 }
 
 sub acquire
 {
 	my $c = $_[0]->{canvas};
-	$_[0]->{subpixel} = $c->antialias || $c->alpha < 255;
+	$_[0]->{subpixel} = $c->antialias;
 }
 
 sub stroke
@@ -639,7 +698,7 @@ sub stroke
 	return 0 unless $_[0]->{canvas};
 	$_[0]->acquire;
 	my $emulated_aa = $_[0]->{antialias} && !$_[0]->{canvas}->antialias;
-	for ( map { @$_ } @{ $_[0]->points }) {
+	for ( $_[0]->points ) {
 		next if 4 > @$_;
 		if ( $emulated_aa ) {
 			return 0 unless $_[0]->{canvas}->new_aa_surface->polyline($_);
@@ -655,14 +714,13 @@ sub fill
 	my ( $self, $fillMode ) = @_;
 	return 0 unless my $c = $self->{canvas};
 	$self->acquire;
-	my @p = $self->points(fill => 1);
 	my $ok = 1;
 	my $save;
 	if ( defined $fillMode ) {
 		$save = $c->fillMode;
 		$c->fillMode($fillMode);
 	}
-	for ( @p ) {
+	for ( $self->points ) {
 		next if 4 > @$_;
 		if ( $self->{antialias} && !$_[0]->{canvas}->antialias) {
 			last unless $ok &= $c->new_aa_surface->fillpoly($_);
@@ -872,7 +930,7 @@ sub contours
 {
 	my $self = shift;
 	my @ret;
-	for my $pp ( map { @$_ } @{ $self->points } ) {
+	for my $pp ( $self->points ) {
 		my @contour;
 		next if @$pp < 2;
 		my $closed = $pp->[0] == $pp->[-2] && $pp->[1] == $pp->[-1];
@@ -1035,6 +1093,9 @@ sub poly2patterns
 
 # Adapted from wine/dlls/gdi32/path.c:WidenPath()
 # (c) Martin Boehme, Huw D M Davies, Dmitry Timoshkov, Alexandre Julliard
+#
+# I keep this for easy debugging and reference, however this implementation
+# doesn't include the line join hinting that is present in render_polyline()
 sub widen_old
 {
 	my ( $self, %opt ) = @_;
@@ -1057,7 +1118,7 @@ sub widen_old
 	my $pp;
 	{
 		local $self->{subpixel} = 1;
-		$pp = [ map { @$_ } @{$self->points} ];
+		$pp = $self->points;
 	}
 	return $dst if $lp eq lp::Null;
 	$pp = poly2patterns($pp, $lp, $lw, !$self->{subpixel}) if $lp ne lp::Solid;
@@ -1252,17 +1313,20 @@ sub widen_new
 		commands => [],
 	);
 
-	my @pp;
+	my ($pp, $hints);
 	{
 		local $self->{subpixel} = 1;
-		@pp = map { @$_ } @{$self->points};
+		($pp, $hints) = $self-> points( hints => 1);
 	}
 
-	for my $p ( @pp ) {
-		next unless @$p;
+	for (my $j = 0; $j < @$pp; $j++ ) {
+		my $p = $pp->[$j];
+		my $h = $hints->[$j];
+
 		my $cmds = $self->{canvas}->render_polyline( $p, %opt,
 			path    => 1,
-			integer => $self->{subpixel} ? 0 : 1,
+			integer => ($self->{subpixel} ? 0 : 1),
+			line_join_hints => $h,
 		);
 
 		for ( my $i = 0; $i < @$cmds;) {
@@ -1294,7 +1358,7 @@ sub widen_new
 sub extents
 {
 	my $self = shift;
-	my @pp = map { @$_ } @{ $self->points };
+	my @pp = $self->points;
 	return unless @pp;
 	my ( $x1, $y1, $x2, $y2 ) = @{$pp[0]}[0,1,0,1];
 	for my $p ( @pp ) {
@@ -1321,7 +1385,7 @@ sub clip
 	$p->clear;
 	$p->set(%opt) if scalar keys %opt;
 	$p->translate($tx, $ty);
-	$p->fillpoly($_) for $self->points(fill => 1);
+	$p->fillpoly($_) for $self->points;
 	return $p->image;
 }
 
@@ -1332,7 +1396,7 @@ sub region
 	$mode //= fm::Winding | fm::Overlay;
 	$rgnop //= rgnop::Union;
 	$reg ? $reg->combine($_, $rgnop) : ($reg = $_)
-		for map { Prima::Region->new( polygon => $_, fillMode => $mode) } $self->points(fill => 1);
+		for map { Prima::Region->new( polygon => $_, fillMode => $mode) } $self->points;
 	return $reg // Prima::Region->new;
 }
 
@@ -1425,9 +1489,11 @@ Adds full ellipse to the path.
 
 =item glyph INDEX, %OPTIONS
 
-Adds glyph outline to the path. C<%OPTIONS> are passed as is to L<Prima::Drawable/renger_glyph>.
-Note that filled glyphs require C<fillMode> without the C<fm::Overlay> bit set and C<fill> option set
-to generate proper shapes with holes.
+Adds glyph outline to the path. C<%OPTIONS> are passed as is to
+L<Prima::Drawable/renger_glyph>, except the C<fill> option.
+
+Note that filled glyphs require C<fillMode> without the C<fm::Overlay> bit set
+and the C<fill> option set to generate proper shapes with holes.
 
 =item line, rline @POINTS
 
@@ -1470,6 +1536,9 @@ except that C<unicode> is deduced automatically based on whether C<TEXT> has utf
 on or off; and an extra option C<cache> with a hash can be used to speed up the function
 with subsequent calls. C<baseline> option is same as L<Prima::Drawable/textOutBaseline>.
 
+Note that filled glyphs require C<fillMode> without the C<fm::Overlay> bit set
+and the C<fill> option set to generate proper shapes with holes.
+
 =back
 
 =head2 Properties
@@ -1594,11 +1663,10 @@ pixels, to be suitable for direct send to the polyline() API call. If PRESCALE
 factor is set, it is used instead to premultiply coordinates of arc anchor
 points used to render the lines.
 
-=item points %opt
+=item points
 
 Runs all accumulated commands, and returns rendered set of points, suitable
-for further calls to either C<Prima::Drawable::polyline> or C<Prima::Drawable::fillpoly>
-depending on the C<$opt{fill}> flag.
+for further calls to C<Prima::Drawable::polyline> and C<Prima::Drawable::fillpoly>.
 
 =item region MODE=fm::Winding|fm::Overlay, RGNOP=rgnop::Union
 
