@@ -31,12 +31,19 @@ use constant TOP       => 10;
 use constant RECT      => 7,8,9,10;
 
 package Prima::AbstractGridViewer;
-use base qw(Prima::Widget Prima::Widget::MouseScroller Prima::Widget::GroupScroller Prima::Widget::ListBoxUtils);
+use base qw(
+	Prima::Widget
+	Prima::Widget::Fader
+	Prima::Widget::GroupScroller
+	Prima::Widget::ListBoxUtils
+	Prima::Widget::MouseScroller
+);
 __PACKAGE__->inherit_core_methods('Prima::Widget::GroupScroller');
 
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	DrawCell      => nt::Action,
 	GetRange      => nt::Action,
 	GetAlignment  => nt::Action,
@@ -1041,19 +1048,29 @@ sub update_prelight_and_pointer
 	my ( $cx, $cy, %hints) = $self-> point2cell( $x, $y );
 	my @prelight = (-1,-1);
 	my @old      = @{$self->{prelight} // [-1,-1]};
+	my $fade     = 1;
 	if ( defined($hints{x_grid}) && $self-> allowChangeCellWidth) {
 		$self-> pointerType( cr::SizeWE);
+		$fade = 0;
 	} elsif ( defined($hints{y_grid}) && $self-> allowChangeCellHeight) {
 		$self-> pointerType( cr::SizeNS);
+		$fade = 0;
 	} else {
 		@prelight = ($cx, $cy) if $hints{normal};
 		$self-> pointerType( cr::Default);
 	}
 
 	if ( join('.', @prelight ) ne join('.', @old)) {
-		$self->{prelight} = ( $prelight[0] < 0 ) ? undef : \@prelight;
-		$self->redraw_cell( @old )      if $old[0]      >= 0;
-		$self->redraw_cell( @prelight ) if $prelight[0] >= 0;
+		$self->redraw_cell( @old ) if $old[0]      >= 0;
+		if ( $prelight[0] >= 0 ) {
+			$self->{prelight} = \@prelight;
+			$self-> redraw_cell( @prelight );
+			$self-> fader_in_mouse_enter unless defined $self->{prelight};
+		} elsif ( $fade ) {
+			$self-> fader_out_mouse_leave;
+		} else {
+			$self-> {prelight} = undef;
+		}
 	}
 }
 
@@ -1179,13 +1196,33 @@ sub on_mousewheel
 	$self-> update_prelight_and_pointer($x, $y);
 }
 
+sub on_mouseenter
+{
+	my $self = shift;
+	$self-> fader_in_mouse_enter;
+}
+
 sub on_mouseleave
+{
+	my $self = shift;
+	$self-> fader_out_mouse_leave;
+}
+
+sub on_fadeout
 {
 	my $self = shift;
 	my $prelight = delete $self->{prelight};
 	$self-> redraw_cell( @$prelight ) if defined $prelight;
 }
 
+sub on_faderepaint
+{
+	my $self = shift;
+	return unless defined $self->{prelight};
+	$self-> fader_cancel_if_unbuffered;
+	$self-> redraw_cell( @{$self->{prelight}} );
+}
+
 sub on_paint
 {
 	my ($self,$canvas)   = @_;
