@@ -5,11 +5,18 @@ use strict;
 use warnings;
 use Prima;
 use Prima::Drawable::Glyphs;
-use base qw(Prima::Widget Prima::Widget::MouseScroller Prima::Widget::UndoActions Prima::Widget::BidiInput);
+use base qw(
+	Prima::Widget
+	Prima::Widget::Fader
+	Prima::Widget::BidiInput
+	Prima::Widget::MouseScroller
+	Prima::Widget::UndoActions
+);
 
 {
 my %RNT = (
-	%{Prima::Dialog-> notification_types()},
+	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	Validate => nt::Notification,
 );
 
@@ -125,13 +132,11 @@ sub on_paint
 	my @clr;
 	my @selClr;
 	@clr = $self-> enabled ?
-		($self-> color,
-			$self->{prelight} ?
-				$self-> prelight_color($self-> backColor) :
-				$self-> backColor
-		) :
+		($self-> color, $self-> backColor) :
 		($self-> disabledColor, $self-> disabledBackColor);
 	@selClr = ($self-> hiliteColor, $self-> hiliteBackColor);
+	$clr[1] = $self->fader_prelight_color($clr[1])
+		if $self->enabled && $self->{mouse_in};
 
 	my $border = $self-> {borderWidth};
 	if ( $self-> skin eq 'flat') {
@@ -838,19 +843,19 @@ sub on_mouseup
 sub on_mouseenter
 {
 	my $self = shift;
-	$self->{prelight} = 1;
 	return unless $self->enabled;
-	$self->repaint;
+	$self->fader_in_mouse_enter;
+	$self->{mouse_in} = 1;
 }
 
 sub on_mouseleave
 {
 	my $self = shift;
-	delete $self->{prelight};
-	return unless $self->enabled;
-	$self->repaint;
+	$self->fader_out_mouse_leave if $self->enabled;
 }
 
+sub on_fadeout { delete shift->{mouse_in} }
+
 sub on_size
 {
 	my $self = $_[0];
