@@ -279,11 +279,7 @@ sub reset_lines
 
 	$self-> begin_paint_info;
 
-	my $text  = $self-> text;
-	my $lines = $self-> text_wrap_shape( $text, $width,
-		options => $opt,
-		rtl     => $self->textDirection,
-	);
+	my $lines = $self-> text_wrap( $self->text, $width // -1, $opt, 1);
 	my $lastRef = pop @{$lines};
 	$self-> {textLines} = scalar @$lines;
 	for( qw( tildeStart tildeEnd tildeLine)) {$self-> {$_} = $lastRef-> {$_}}
@@ -592,7 +588,8 @@ Default value: C<undef>.
 
 =item hotKey CHAR
 
-A key that the label will react to if pressed, even when out of focus.
+A key (defined by CHAR) that the label will react to if pressed, if the label has the focus
+The combination ALT + Key works always if the label has the focus or not
 
 =item showAccelChar BOOLEAN
 
