@@ -22,11 +22,19 @@ eval 'use constant Grid => 1 + MaxId;' unless exists $ci::{Grid};
 }
 
 package Prima::AbstractListViewer;
-use base qw(Prima::Widget Prima::Widget::MouseScroller Prima::Widget::GroupScroller Prima::Widget::ListBoxUtils);
+use base qw(
+	Prima::Widget
+	Prima::Widget::Fader
+	Prima::Widget::GroupScroller
+	Prima::Widget::ListBoxUtils
+	Prima::Widget::MouseScroller
+);
+__PACKAGE__->inherit_core_methods('Prima::Widget::GroupScroller');
 
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	SelectItem  => nt::Default,
 	DrawItem    => nt::Action,
 	Stringify   => nt::Action,
@@ -43,15 +51,11 @@ sub profile_default
 	my %prf = (
 		align          => ta::Left,
 		autoHeight     => 1,
-		autoHScroll    => 1,
-		autoVScroll    => 1,
-		borderWidth    => 2,
 		extendedSelect => 0,
 		drawGrid       => 1,
 		dragable       => 0,
 		focusedItem    => -1,
 		gridColor      => cl::Black,
-		hScroll        => 0,
 		integralHeight => 0,
 		integralWidth  => 0,
 		itemHeight     => $def-> {font}-> {height},
@@ -61,13 +65,9 @@ sub profile_default
 		offset         => 0,
 		topItem        => 0,
 		scaleChildren  => 0,
-		scrollBarClass => 'Prima::ScrollBar',
-		hScrollBarProfile=>{},
-		vScrollBarProfile=>{},
 		selectable     => 1,
 		selectedItems  => [],
 		vertical       => 1,
-		vScroll        => 1,
 		widgetClass    => wc::ListBox,
 	);
 	@$def{keys %prf} = values %prf;
@@ -95,8 +95,6 @@ sub profile_check_in
 	$p-> { integralWidth} = 1 if
 		! exists $p->{integralWidth} and
 		$multi_column and not($vertical);
-	$p-> {autoHScroll} = 0 if exists $p-> {hScroll};
-	$p-> {autoVScroll} = 0 if exists $p-> {vScroll};
 }
 
 sub init
@@ -105,9 +103,9 @@ sub init
 	for ( qw( lastItem topItem focusedItem))
 		{ $self-> {$_} = -1; }
 	for ( qw(
-		autoHScroll autoVScroll scrollTransaction gridColor dx dy hScroll vScroll
+		scrollTransaction gridColor dx dy 
 		itemWidth offset multiColumn count autoHeight multiSelect
-		extendedSelect borderWidth dragable ))
+		extendedSelect dragable ))
 		{ $self-> {$_} = 0; }
 	for ( qw( drawGrid itemHeight integralWidth integralHeight vertical align))
 		{ $self-> {$_} = 1; }
@@ -115,11 +113,10 @@ sub init
 	my %profile = $self-> SUPER::init(@_);
 	$self-> setup_indents;
 	$self-> {selectedItems} = {} unless $profile{multiSelect};
-	$self->{$_} = $profile{$_} for qw(scrollBarClass hScrollBarProfile vScrollBarProfile);
 	for ( qw(
-		autoHScroll autoVScroll gridColor hScroll vScroll offset multiColumn
+		gridColor offset multiColumn
 		itemHeight autoHeight itemWidth multiSelect extendedSelect integralHeight
-		integralWidth focusedItem topItem selectedItems borderWidth dragable
+		integralWidth focusedItem topItem selectedItems dragable
 		vertical drawGrid align))
 		{ $self-> $_( $profile{ $_}); }
 	$self-> reset;
@@ -580,6 +577,7 @@ sub update_prelight
 	my $prelight;
 	if ( $y >= $a[1] && $y < $a[3] && $x >= $a[0] && $x < $a[2]) {
 		my ($item, $aux) = $self-> point2item( $x, $y);
+		$item = -1 if $item >= $self->{count};
 		$prelight = ($item >= 0) ? $item : undef unless defined $aux;
 	}
 	if ( ( $self->{prelight} // -1 ) != ( $prelight // -1 )) {
@@ -587,7 +585,12 @@ sub update_prelight
 			$self->{prelight} // (),
 			$prelight // ()
 		);
-		$self->{prelight} = $prelight;
+		if ( defined $prelight ) {
+			$self-> fader_in_mouse_enter unless defined $self->{prelight};
+			$self->{prelight} = $prelight;
+		} else {
+			$self-> fader_out_mouse_leave;
+		}
 		$self->redraw_items( @redraw );
 	}
 }
@@ -680,11 +683,31 @@ sub on_mouseup
 	$self-> notify(q(DragItem), @dragnotify) if @dragnotify;
 }
 
+sub on_mouseenter
+{
+	my $self = shift;
+	$self-> fader_in_mouse_enter;
+}
+
 sub on_mouseleave
 {
 	my $self = shift;
-	my $prelight = delete $self->{prelight};
-	$self-> redraw_items( $prelight ) if defined $prelight;
+	$self-> fader_out_mouse_leave;
+}
+
+sub on_fadeout
+{
+	my $self = shift;
+	my $p = delete $self->{prelight};
+	$self->redraw_items($p) if defined $p; # eventual double prelight
+}
+
+sub on_faderepaint
+{
+	my $self = shift;
+	return unless defined $self->{prelight};
+	$self-> fader_cancel_if_unbuffered;
+	$self-> redraw_items( $self->{prelight} );
 }
 
 sub on_mousewheel
