@@ -15,7 +15,6 @@ sub new
 	return $self;
 }
 
-sub check_width   { 10 }
 sub y_offset      { 5 }
 
 sub selectable    { 1 }
@@ -52,7 +51,7 @@ sub size { 0, shift->y_offset * 2 }
 
 sub draw
 {
-	my ( $self, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
+	my ( $self, $owner, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
 	$y += $h / 2 - 1;
 	$canvas->color($$colors[ci::Light3DColor]);
 	$canvas->line( $x - 1, $y, $x + $w - 1, $y);
@@ -67,8 +66,8 @@ use base qw(Prima::Menu::Item);
 
 sub is_separator { 0 }
 
-# horizontal: (CHECK=EM) EM/2 TEXT (EM/2 ACCEL)? EM/2
-# vertical:    CHECK=EM  EM/2 TEXT (EM/2 ACCEL)? EM/2 DOWN=EM
+# horizontal: (CHECK=2*EM) EM/2 TEXT (EM/2 ACCEL)? EM/2
+# vertical:    CHECK=2*EM  EM/2 TEXT (EM/2 ACCEL)? EM/2 DOWN=EM
 
 sub em { $_[0]-> {em_width} }
 
@@ -96,7 +95,7 @@ sub size
 		$h = $asz[1] if $h > $asz[1];
 		$sz[1] = $h if $sz[1] < $h;
 	} else {
-		$icon_width = $em # space for *
+		$icon_width = 2 * $em # space for *
 			if $self->vertical || $self->checked || $self->autoToggle;
 	}
 
@@ -121,7 +120,7 @@ sub size
 
 sub draw_bitmap
 {
-	my ( $self, $canvas, $colors, $icon, $x, $y, $w, $h) = @_;
+	my ( $self, $owner, $canvas, $colors, $icon, $x, $y, $w, $h) = @_;
 
 	my $key = "$icon";
 
@@ -230,7 +229,7 @@ sub draw_bitmap
 
 sub draw
 {
-	my ( $self, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
+	my ( $self, $owner, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
 	my $enabled    = $self->enabled;
 	my $vertical   = $self->vertical;
 	my $checked    = $self->checked;
@@ -243,25 +242,48 @@ sub draw
 	my $em = $self-> em;
 	my $y_offset = $self-> y_offset;
 
-	my ($draw_check, $draw_accel, $draw_submenu);
+	my ($draw_check, $draw_accel, $draw_submenu, $draw_check_aa);
 
 	my $lw = 3;
 	if ( my $icon = $self-> icon ) {
-		$self-> draw_bitmap( $canvas, $colors, $icon, $x + 2, $y + $y_offset, $self->{icon_width}, $h - $y_offset * 2 );
+		$self-> draw_bitmap( $owner, $canvas, $colors, $icon, $x + 2, $y + $y_offset, $self->{icon_width}, $h - $y_offset * 2 );
 	} elsif ( $checked ) {
-		my $Y  = $y + $h / 2;
-		my $D  = $em * 0.25;
-		my $X  = $x + $lw / 2 + $D / 2 + ( $self->{icon_width} - $em) / 2;
-		$draw_check = [$X, $Y, $X + $D, $Y - $D, $X + $D * 3, $Y + $D];
+		my $font = $canvas->font;
+		my $Dx = $em * 0.25;
+		my $Dy = ($font->{ascent} - $font->{internalLeading}) / 2;
+		my $Y  = $y + $h / 2 + $font->{descent};
+		my $X  = $x + $lw / 2 + $Dx / 2 + ( $self->{icon_width} - $em) / 2;
+		my $Xw = $font->{height} / 6;
+		$Xw = 3 if $Xw < 3;
+		$Xw /= 2;
+		$Y -= $Xw;
+		$draw_check    = [$X, $Y, $X + $Dx, $Y - $Dy, $X + $Dx * 3, $Y + $Dy];
+		$draw_check_aa = [
+			$X - $Xw, $Y,
+			$X + $Dx, $Y - $Dy - $Xw,
+			$X + $Dx * 3 + $lw, $Y + $Dy,
+			$X + $Dx, $Y - $Dy + $Xw,
+			$X, $Y - $Xw,
+		];
 	} elsif ( $autotoggle ) {
 		my $Y  = $y + $h / 2;
 		my $D  = $em * 0.5;
 		my $X  = $x + $D / 4 + ($self->{icon_width} - $em) / 2;
 		my @r = ( $X, $Y - $D, $X + $D * 2, $Y + $D);
 		my $c1 = $$colors[$enabled ? ci::Dark3DColor : ci::DisabledText];
-		my $c2 = $enabled ? 0x404040 : $$colors[ci::Light3DColor];
-		$canvas-> rect3d( @r, 1, $c1, $c2);
-		$canvas-> rect3d( $r[0]+1,$r[1]+1,$r[2]-1,$r[3]-1, 1, $$colors[ci::Light3DColor], $c1);
+		if ( $owner->skin eq 'flat') {
+			my $lw = $canvas->font->{height} / 20;
+			$lw = 1 if $lw < 1;
+			$canvas-> lineWidth( $lw );
+			$canvas-> color($c1);
+			$canvas-> lineJoin(lj::Miter);
+			$canvas-> rectangle(@r);
+			$canvas-> lineWidth(1.0);
+		} else {
+			my $c2 = $enabled ? 0x404040 : $$colors[ci::Light3DColor];
+			$canvas-> rect3d( @r, 1, $c1, $c2);
+			$canvas-> rect3d( $r[0]+1,$r[1]+1,$r[2]-1,$r[3]-1, 1, $$colors[ci::Light3DColor], $c1);
+		}
 	}
 
 	$x += $self-> {icon_width} + $em / 2;
@@ -284,33 +306,45 @@ sub draw
 	$w -= $em * ($vertical ? 1.5 : 0.5 );
 
 	if ( $draw_check || $draw_accel || $draw_submenu ) {
-		$canvas-> lineEnd(le::Round) if $draw_check;
+		return unless $canvas->graphic_context_push;
+		$canvas->antialias(1) if $draw_check || $draw_submenu;
+		if ($draw_check) {
+			unless ( $canvas-> antialias ) {
+				$canvas->lineWidth($lw);
+				$canvas->lineEnd(le::Round);
+				undef $draw_check_aa;
+			}
+		}
 		unless ( $self-> enabled ) {
 			$canvas->color( $$colors[ci::Light3DColor] );
 			my @tr = $canvas->translate;
-			$canvas->translate($tr[0] + 1, $tr[1] - 1);
-			if ($draw_check) {
-				$canvas->lineWidth($lw);
-				$canvas->polyline($draw_check);
-				$canvas->lineWidth(1);
+			if ( $draw_check ) {
+				if ( $draw_check_aa ) {
+					$canvas->fillpoly($draw_check_aa);
+				} else {
+					$canvas->polyline($draw_check);
+				}
 			}
-			$canvas->text_out( @$draw_accel ) if $draw_accel;
+			$canvas->text_out( @$draw_accel) if $draw_accel;
 			$canvas->fillpoly($draw_submenu) if $draw_submenu;
 			$canvas->translate(@tr);
 			$canvas->color( $$colors[ci::DisabledText] );
 		} else {
 			$canvas->color( $$colors[$selected ? ci::HiliteText : ci::NormalText] );
 		}
-		if ($draw_check) {
-			$canvas->lineWidth($lw);
-			$canvas->polyline($draw_check);
-			$canvas->lineWidth(1);
+		if ( $draw_check ) {
+			if ( $draw_check_aa ) {
+				$canvas->fillpoly($draw_check_aa);
+			} else {
+				$canvas->polyline($draw_check);
+			}
 		}
 		$canvas->text_out( @$draw_accel ) if $draw_accel;
-		$canvas->fillpoly($draw_submenu) if $draw_submenu;
+		$canvas->fillpoly($draw_submenu)  if $draw_submenu;
+		$canvas->graphic_context_pop;
 	}
 
-	$self-> draw_entry( $canvas, $colors, $x, $y, $w, $h, $selected);
+	$self-> draw_entry( $owner, $canvas, $colors, $x, $y, $w, $h, $selected);
 }
 
 sub entry_size { 0,0 }
@@ -328,7 +362,7 @@ sub entry_size
 
 sub draw_entry
 {
-	my ( $self, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
+	my ( $self, $owner, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
 
 	my $text = $self-> text;
 	$y += ( $h - $canvas-> font-> height ) / 2;
@@ -359,6 +393,7 @@ sub autoToggle { 0 }
 sub accel      { "" }
 sub key        { 0 }
 sub data       { undef }
+sub icon       { undef }
 sub image      { undef }
 sub submenu    { undef }
 sub items      { undef }
@@ -390,8 +425,8 @@ sub entry_size
 
 sub draw_entry
 {
-	my ( $self, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
-	$self-> draw_bitmap( $canvas, $colors, $self-> image, $x, $y, $w, $h );
+	my ( $self, $owner, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
+	$self-> draw_bitmap( $owner, $canvas, $colors, $self-> image, $x, $y, $w, $h );
 }
 
 package Prima::Menu::Item::Custom;
@@ -408,9 +443,11 @@ sub size
 
 sub draw
 {
-	my ( $self, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
+	my ( $self, $owner, $canvas, $colors, $x, $y, $w, $h, $selected ) = @_;
 	my $cb   = $self->options->{onPaint} or return;
+	return unless $canvas->graphic_context_push;
 	$cb->( $canvas-> menu, $self, $canvas, $selected, $x, $y, $x + $w - 1, $y + $h - 1);
+	$canvas->graphic_context_pop;
 }
 
 package Prima::Menu::Common;
@@ -463,9 +500,9 @@ sub init
 	$self->{selectedItem} = -1;
 	for ( qw( borderSize ))
 		{ $self-> {$_} = 1; }
+	$self->{lock_reset} = 1;
 	my %profile = $self-> SUPER::init(@_);
 
-	$self->{lock_reset} = 1;
 	for ( qw( borderSize parent parentIndex ))
 		{ $self-> $_( $profile{ $_}); }
 	delete $self->{lock_reset};
@@ -473,6 +510,15 @@ sub init
 	return %profile;
 }
 
+sub skin
+{
+	return $_[0]->SUPER::skin unless $#_;
+	my $self = shift;
+	$self->SUPER::skin($_[1]);
+	$self->borderSize(1) if $self->SUPER::skin eq 'flat';
+	$self->repaint;
+}
+
 sub borderSize
 {
 	return $_[0]->{borderSize} unless $#_;
@@ -760,10 +806,19 @@ sub on_paint
 	my @sz = $self->size;
 	my $caches = $self->{cache};
 	if ( $self->{vertical} ) {
-		$self->rect_bevel( $canvas, 0, 0, $sz[0]-1, $sz[1]-1,
-			width => $self->{borderSize}, 
-			fill => $c[ci::Normal],
-		);
+		if ( $self-> skin eq 'flat') {
+			$canvas-> graphic_context( sub {
+				$canvas-> color( $self-> dark3DColor ); 
+				$canvas-> rectangle(0, 0, $sz[0]-1, $sz[1]-1);
+				$canvas-> color( $c[ci::Normal] );
+				$canvas-> bar( 1, 1, $sz[0]-2, $sz[1]-2);
+			});
+		} else {
+			$self->rect_bevel( $canvas, 0, 0, $sz[0]-1, $sz[1]-1,
+				width => $self->{borderSize}, 
+				fill => $c[ci::Normal],
+			);
+		}
 	} else {
 		$self->clear;
 	}
@@ -773,7 +828,7 @@ sub on_paint
 		next unless $cache->[OBJECT];
 		my @o = @{$cache}[X, Y];
 		my @s = @{$cache}[WIDTH, HEIGHT];
-		$cache->[OBJECT]->draw( $canvas, \@c, @$cache[X,Y,WIDTH,HEIGHT], $i == $self->{selectedItem});
+		$cache->[OBJECT]->draw( $self, $canvas, \@c, @$cache[X,Y,WIDTH,HEIGHT], $i == $self->{selectedItem});
 	}
 }
 
@@ -1197,6 +1252,7 @@ sub cancel
 	}
 	$self->{submenu} = undef;
 	$self->{selectedItem} = -1;
+	return unless $self->alive;
 	$self->focused(0);
 	$self->repaint;
 	$self-> notify(q(MenuLeave));
