@@ -5,12 +5,17 @@ use warnings;
 use Prima qw(Widget::ScrollWidget);
 
 package Prima::TabSet;
-use base qw(Prima::Widget Prima::Widget::MouseScroller);
+use base qw(
+	Prima::Widget
+	Prima::Widget::Fader
+	Prima::Widget::MouseScroller
+);
 
 
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	DrawTab     => nt::Action,
 	MeasureTab  => nt::Action,
 );
@@ -202,6 +207,12 @@ sub on_mouseup
 	$self-> {mouseTransaction} = undef;
 }
 
+sub on_mouseenter
+{
+	my $self = shift;
+	return unless $self->enabled;
+	$self-> fader_in_mouse_enter;
+}
 
 sub on_mousemove
 {
@@ -210,8 +221,13 @@ sub on_mousemove
 		if ( $self-> enabled ) {
 			my $prelight = $self-> x2pos($x);
 			if (( $prelight // '') ne ($self->{prelight} // '')) {
-				$self->{prelight} = $prelight;
-				$self-> repaint;
+				if ( defined($prelight)) {
+					$self-> fader_in_mouse_enter unless defined $self->{prelight};
+					$self->{prelight} = $prelight;
+				} else {
+					$self->fader_out_mouse_leave;
+				}
+				$self->repaint;
 			}
 		}
 		return;
@@ -227,9 +243,12 @@ sub on_mousemove
 sub on_mouseleave
 {
 	my $self = shift;
-	$self-> repaint if defined( delete $self->{prelight} );
+	return unless $self->enabled;
+	$self-> fader_out_mouse_leave;
 }
 
+sub on_fadeout { delete shift->{prelight} }
+
 sub on_mouseclick
 {
 	my $self = shift;
@@ -447,7 +466,9 @@ sub on_drawtab
 	my $colorset = $self->{colorset};
 	my $color = ( $self-> {colored} && !$flat && ( $i >= 0)) ?
 		( $colorset->[ $i % scalar @$colorset]) : $$clr[1];
-	$color = $self-> prelight_color($color) if ($self->{prelight} // '') eq ($i // '');
+	if (($self->{prelight} // '') eq ($i // '')) {
+		$color = $self->fader_prelight_color($color);
+	}
 	$canvas-> color($color);
 	$canvas-> fillpoly( $poly);
 	$canvas-> fillpoly( $poly2) if $poly2;
