@@ -54,26 +54,29 @@ sub init_image_triangle
 	my $iw = int( $uis * 11 + .5);
 	$iw++ unless $iw % 2;
 	my @imageSize = ($iw, $iw);
-	my $lw = int( $uis + .5);
-	$lw-- if $lw > 1 && $lw % 2;
+	my $lw = $::application->can_draw_alpha ? $uis : int($uis);
 	my @c2 = map { int ( $_ / 2 ) } @imageSize;
+	my $lw2 = $lw * 2;
 
 	my @images;
 	for my $i (0,1) {
 		$images[$i] = Prima::DeviceBitmap->new(
+			antialias => 1,
 			size      => \@imageSize,
-			backColor => cl::White,
-			color     => cl::Black,
+			backColor => cl::Back | wc::ListBox,
+			color     => cl::Fore | wc::ListBox,
 		);
 		$images[$i]->clear;
 		$images[$i]->lineWidth($lw);
+		$images[$i]->lineJoin(lj::Miter);
+		$images[$i]->translate(0, $imageSize[1]*0.25) if $i;
 		$images[$i]->polyline( [
 			$i ? (
-				0, $c2[1], $imageSize[0]-1, $c2[1],
-				$c2[0], 0, 0, $c2[1]
+				$lw2, $c2[1], $imageSize[0]-1-$lw2, $c2[1],
+				$c2[0], $lw2, $lw2, $c2[1]
 			) : (
-				$c2[0], 0, $c2[0], $imageSize[1]-1,
-				$imageSize[0]-1, $c2[1], $c2[0], 0
+				$c2[0], $lw2, $c2[0], $imageSize[1]-1-$lw2,
+				$imageSize[0]-1-$lw2, $c2[1], $c2[0], $lw2
 			)
 		]);
 	}
@@ -99,7 +102,14 @@ sub icon
 }
 
 package Prima::OutlineViewer;
-use base qw(Prima::Widget Prima::Widget::MouseScroller Prima::Widget::GroupScroller Prima::Widget::ListBoxUtils);
+use base qw(
+	Prima::Widget
+	Prima::Widget::Fader
+	Prima::Widget::MouseScroller
+	Prima::Widget::GroupScroller
+	Prima::Widget::ListBoxUtils
+);
+__PACKAGE__->inherit_core_methods('Prima::Widget::GroupScroller');
 
 use constant DATA     => 0;
 use constant DOWN     => 1;
@@ -119,6 +129,7 @@ use constant SELECTED => 4;
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	SelectItem  => nt::Default,
 	DrawItem    => nt::Action,
 	Stringify   => nt::Action,
@@ -136,16 +147,13 @@ sub profile_default
 	my $def = $_[ 0]-> SUPER::profile_default;
 	my %prf = (
 		autoHeight     => 1,
-		autoHScroll    => 1,
-		autoVScroll    => 1,
-		borderWidth    => 2,
 		extendedSelect => 0,
 		dragable       => 1,
 		drawLines      => undef,
-		hScroll        => 0,
 		focusedItem    => -1,
 		iconCollapsed  => undef,
 		iconExpanded   => undef,
+		iconStyle      => 'default',
 		indent         => int( 12 * $::application->uiScaling + .5),
 		itemHeight     => $def-> {font}-> {height},
 		items          => [],
@@ -153,13 +161,8 @@ sub profile_default
 		topItem        => 0,
 		offset         => 0,
 		scaleChildren  => 0,
-		scrollBarClass => 'Prima::ScrollBar',
-		hScrollBarProfile=>{},
-		vScrollBarProfile=>{},
 		selectable     => 1,
 		showItemHint   => 1,
-		style          => 'default',
-		vScroll        => 1,
 		widgetClass    => wc::ListBox,
 	);
 	@$def{keys %prf} = values %prf;
@@ -174,8 +177,6 @@ sub profile_check_in
 	$p-> { autoHeight} = 0 if
 		exists $p-> { itemHeight}
 		&& !exists $p-> {autoHeight};
-	$p-> {autoHScroll} = 0 if exists $p-> {hScroll};
-	$p-> {autoVScroll} = 0 if exists $p-> {vScroll};
 	$p-> {multiSelect} = 1 if
 		exists $p-> { extendedSelect}
 		&& $p-> {extendedSelect}
@@ -189,20 +190,19 @@ sub init
 	my $self = shift;
 	for ( qw( topItem focusedItem))
 		{ $self-> {$_} = -1; }
-	for ( qw( autoHScroll autoVScroll scrollTransaction dx dy hScroll vScroll
-		offset count autoHeight borderWidth multiSelect extendedSelect
+	for ( qw( scrollTransaction dx dy 
+		offset count autoHeight multiSelect extendedSelect
 		rows maxWidth hintActive showItemHint dragable))
 		{ $self-> {$_} = 0; }
 	for ( qw( itemHeight indent))
 		{ $self-> {$_} = 1; }
 	$self-> {items}      = [];
-	$self-> {style}      = 'default';
+	$self-> {iconStyle}  = 'default';
 	my %profile = $self-> SUPER::init(@_);
 	$self-> setup_indents;
-	$self->{$_} = $profile{$_} for qw(scrollBarClass hScrollBarProfile vScrollBarProfile);
-	for ( qw( autoHScroll autoVScroll hScroll vScroll offset itemHeight autoHeight borderWidth
+	for ( qw( offset itemHeight autoHeight 
 		indent items focusedItem topItem showItemHint dragable multiSelect extendedSelect
-		style iconCollapsed iconExpanded drawLines
+		iconStyle skin iconCollapsed iconExpanded drawLines
 	))
 		{ $self-> $_( $profile{ $_}); }
 	$self-> reset;
@@ -712,6 +712,7 @@ sub update_prelight
 		$y = $a[3] - $y;
 		$item = $self-> {topItem} + int( $y / $self-> {itemHeight});
 	}
+	undef $item if $item >= $self->{count};
 
 	if ( $self-> {showItemHint} ) {
 		if ( defined $item ) {
@@ -726,7 +727,12 @@ sub update_prelight
 			$self->{prelight} // (),
 			$item // ()
 		);
-		$self->{prelight} = $item;
+		if ( defined $item ) {
+			$self-> fader_in_mouse_enter unless defined $self->{prelight};
+			$self->{prelight} = $item;
+		} else {
+			$self-> fader_out_mouse_leave;
+		}
 		$self->redraw_items( @redraw );
 	}
 }
@@ -810,11 +816,31 @@ sub on_mousewheel
 	$self-> update_prelight($x,$y);
 }
 
+sub on_mouseenter
+{
+	my $self = shift;
+	$self-> fader_in_mouse_enter;
+}
+
 sub on_mouseleave
 {
 	my $self = shift;
-	my $prelight = delete $self->{prelight};
-	$self-> redraw_items( $prelight ) if defined $prelight;
+	$self-> fader_out_mouse_leave;
+}
+
+sub on_fadeout
+{
+	my $self = shift;
+	my $p = delete $self->{prelight};
+	$self->redraw_items($p) if defined $p; # eventual double prelight
+}
+
+sub on_faderepaint
+{
+	my $self = shift;
+	return unless defined $self->{prelight};
+	$self-> fader_cancel_if_unbuffered;
+	$self-> redraw_items( $self->{prelight} );
 }
 
 sub on_enable  { $_[0]-> repaint; }
@@ -1092,6 +1118,8 @@ sub redraw_items
 	my $ih = $self-> {itemHeight};
 
 	my %match;
+	my $buffered = $self->buffered;
+	$self->buffered(1) unless $buffered;
 	for my $i ( @items ) {
 		next unless $i >= 0 && $i >= $self-> {topItem} && $i <= $self-> {topItem} + $self-> {rows};
 		next if $match{$i}++;
@@ -1101,6 +1129,10 @@ sub redraw_items
 			$a[2], $a[3] - $i * $ih
 		);
 	}
+	unless ($buffered) {
+		$self->update_view;
+		$self->buffered(0);
+	}
 }
 
 sub draw_items
@@ -1331,8 +1363,7 @@ sub set_offset
 	}
 
 	$self-> makehint(0);
-	$self-> scroll( $oldOfs - $offset, 0,
-						clipRect => \@a);
+	$self-> scroll( $oldOfs - $offset, 0, clipRect => \@a);
 }
 
 sub set_top_item
@@ -1354,8 +1385,7 @@ sub set_top_item
 		$self-> {scrollTransaction} = 0;
 	}
 
-	$self-> scroll( 0, ($topItem - $oldTop) * $ih,
-						clipRect => \@a);
+	$self-> scroll( 0, ($topItem - $oldTop) * $ih, clipRect => \@a);
 }
 
 
@@ -1428,15 +1458,29 @@ sub iconExpanded
 	$_[0]-> repaint;
 }
 
-sub style
+sub iconStyle
 {
-	return $_[0]-> {style} unless $#_;
+	return $_[0]-> {iconStyle} unless $#_;
 	my ( $self, $style ) = @_;
 	$self->iconCollapsed( Prima::Outlines->icon( type => 'collapsed', style => $style) );
 	$self->iconExpanded(  Prima::Outlines->icon( type => 'expanded' , style => $style) );
 	$self->drawLines( $style ne 'triangle' );
 }
 
+sub skin
+{
+	return $_[0]->SUPER::skin unless $#_;
+	my $self = shift;
+	$self->SUPER::skin($_[1]);
+	my $skin = $self->SUPER::skin;
+	if ($skin eq 'flat') {
+		$self->iconStyle('triangle');
+	} elsif ( $skin eq 'classic') {
+		$self->iconStyle('plusminus');
+	}
+	$self->repaint;
+}
+
 sub get_index
 {
 	my ( $self, $item) = @_;
@@ -2207,7 +2251,7 @@ Prima::Outlines - tree view widgets
 =for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/outline.gif">
 
 	my $outline = Prima::StringOutline-> create(
-		style => 'triangle',
+		iconStyle => 'triangle',
 		...
 	);
 
@@ -2324,6 +2368,12 @@ Sets the image that is to be displayed when a tree branch is collapsed
 
 Sets the image that is to be displayed when a tree branch is expanded
 
+=item iconStyle STYLE
+
+Sets visual style, one of: C<default>, C<plusminus>, C<triangle>.
+
+The default style is set in C<$Prima::Outlines::default_style> and is currently 'plusminus'
+
 =item indent INTEGER
 
 Width in pixels of the indent between item levels.
@@ -2379,12 +2429,6 @@ See also: L<makehint>.
 
 Default value: 1
 
-=item style STYLE
-
-Sets visual style, one of: C<default>, C<plusminus>, C<triangle>.
-
-The default style is set in C<$Prima::Outlines::default_style> and is currently 'plusminus'
-
 =item topItem INTEGER
 
 Selects the first item drawn.
