@@ -64,6 +64,8 @@ sub save_state
 	);
 }
 
+sub abandon_state { delete $_[0]->{save_state} }
+
 sub restore_state
 {
 	my $self = $_[0];
@@ -139,7 +141,7 @@ sub spool
 
 sub is_custom_line
 {
-	my ($self, $for_closed_shapes) = shift;
+	my ($self, $for_closed_shapes) = @_;
 	return $self->{lineEnd_flags} ? (
 		$for_closed_shapes ? ( $self->{lineEnd_flags} & 2 ) : 1
 	) : 0;
@@ -174,7 +176,10 @@ sub update_custom_line
 	$le //= $self->SUPER::lineEnd;
 	$self->{lineEnd_flags} = ref($le) ? 1 : 0;
 	if ( $self->{lineEnd_flags} ) {
-		$self->{lineEnd_flags} |= 2 if defined($le->[2]) || defined($le->[3]);
+		$self->{lineEnd_flags} |= 2 unless # unsafe for closed shapes
+			(!ref($le->[0]) && (( $le->[1] // $le->[0] ) eq $le->[0])) ||
+			($self->SUPER::linePattern eq lp::Solid)
+		;
 	} else {
 		$self-> {changed}-> {lineEnd} = 1;
 	}
@@ -266,11 +271,10 @@ sub clipRect
 	$_[0]-> change_transform;
 }
 
-sub matrix
+sub set_matrix
 {
-	return $_[0]->SUPER::matrix unless $#_;
 	my ( $self, @m ) = @_;
-	$self->SUPER::matrix(@m);
+	$self->SUPER::set_matrix(@m);
 	$self->change_transform;
 }
 
@@ -284,13 +288,8 @@ sub region
 	return undef;
 }
 
-sub scale
-{
-	my ( $self, @scale ) = @_;
-	my $m = $self-> matrix;
-	$m->scale(@scale);
-	$self->matrix($m);
-}
+sub scale  { shift-> matrix->scale(@_) }
+sub rotate { shift-> matrix->rotate(@_) }
 
 sub reversed
 {
@@ -300,15 +299,6 @@ sub reversed
 	$self-> calc_page;
 }
 
-sub rotate
-{
-	my ( $self, $angle ) = @_;
-	return if $angle == 0.0;
-	my $m = $self-> matrix;
-	$m->rotate($angle);
-	$self->matrix($m);
-}
-
 sub resolution
 {
 	return @{$_[0]-> {resolution}} unless $#_;
@@ -684,7 +674,7 @@ sub primitive
 	my $src = Prima::Drawable::Path->new( undef, subpixel => 1 );
 	$src->$cmd(@param);
 
-	my @pp = map { @$_ } @{$src->points};
+	my @pp = $src->points;
 	for my $p ( @pp ) {
 		next unless @$p;
 		my $cmds = $self->render_polyline( $p, path => 1, integer => 0);
@@ -910,7 +900,7 @@ sub stroke
 		subpixel => 1,
 		commands => $self->commands,
 	);
-	for ( map { @$_ } @{ $path->points }) {
+	for ( $path->points ) {
 		next if 4 > @$_;
 		$c->primitive( polyline => $_ );
 	}
