@@ -97,7 +97,7 @@ sub change_transform
 
 	$self-> emit_content("h @pm re W n");
 
-	my $m  = $self-> matrix;
+	my $m = $self-> get_matrix;
 	if ( $self->{reversed}) {
 		$$m[5] -= ($self->point2pixel($pm[2]))[0];
 		$m->rotate(90);
@@ -498,7 +498,7 @@ sub abort_doc
 	return unless $self-> {can_draw};
 	$self-> {can_draw} = 0;
 	$self-> SUPER::end_paint;
-	$self-> restore_state;
+	$self-> abandon_state;
 	delete $self-> {$_} for
 		qw (save_state ps_data changed );
 }
