@@ -96,7 +96,7 @@ sub change_transform
 		$doClip  = grep { $_ != 0 } @cr;
 	}
 
-	my $m = $self-> matrix;
+	my $m = $self-> get_matrix;
 	my $doMx = !$m->is_identity;
 
 	if ( !$doClip && !$doMx && !$rg) {
@@ -366,7 +366,7 @@ sub abort_doc
 	return unless $self-> {can_draw};
 	$self-> {can_draw} = 0;
 	$self-> SUPER::end_paint;
-	$self-> restore_state;
+	$self-> abandon_state;
 	delete $self-> {$_} for
 		qw (save_state ps_data changed page_prefix);
 }
