@@ -11,7 +11,11 @@ use vars qw(@ISA @stdMetrics);
 use strict;
 use warnings;
 use Prima;
-use base qw(Prima::Widget Prima::Widget::MouseScroller);
+use base qw(
+	Prima::Widget
+	Prima::Widget::Fader
+	Prima::Widget::MouseScroller
+);
 
 @stdMetrics = Prima::Application-> get_default_scrollbar_metrics;
 
@@ -41,6 +45,7 @@ sub profile_default
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	Track => nt::Default,
 );
 
@@ -116,10 +121,12 @@ sub draw_pad
 		if ( $self->{$part}->{pressed}) {
 			$clr = $hbc;
 		} elsif ( $self->enabled) {
-			my $pct = (( $self->{prelight} // '') eq $part) ? 0.33 : 0.66;
+			my $pct = 0.33;
+			$pct *= 1 + ( $self-> fader_current_value // 1 )
+				if ( $self->{prelight} // '') eq $part;
 			$clr = cl::blend(
-				$self->map_color( $hbc ),
 				$self->map_color( $base_color ),
+				$self->map_color( $hbc ),
 				$pct
 			);
 		} else {
@@ -129,7 +136,8 @@ sub draw_pad
 		$canvas-> bar( @{$self-> {$part}-> {rect}} );
 	} else {
 		if ( defined $self->{prelight} && $self->{prelight} eq $part && $self->enabled ) {
-			$base_color = $self-> prelight_color($base_color, 1.25);
+			my $hc = $self-> prelight_color($base_color, 1.25);
+			$base_color = cl::blend( $base_color, $hc, $self->fader_current_value // 1);
 		}
 		my @palette = ( $base_color, $self->dark3DColor );
 		my @spline  = ( 1, 0 );
@@ -493,6 +501,12 @@ sub on_mouseup
 	}
 }
 
+sub on_mouseenter
+{
+	my $self = shift;
+	$self-> fader_in_mouse_enter if $self->enabled;
+}
+
 sub on_mousemove
 {
 	my ( $self, $mod, $x, $y) = @_;
@@ -552,9 +566,12 @@ sub on_mousemove
 sub on_mouseleave
 {
 	my $self = shift;
-	$self-> repaint if defined( delete $self->{prelight} );
+	return unless $self->enabled;
+	$self-> fader_out_mouse_leave;
 }
 
+sub on_fadeout { delete shift->{prelight} }
+
 sub on_mousewheel
 {
 	my ( $self, $mod, $x, $y, $z) = @_;
