@@ -1176,7 +1176,18 @@ use constant Dual        => 2;
 
 package Prima::Slider;
 use vars qw(@ISA);
-@ISA = qw(Prima::AbstractSlider);
+use base qw(
+	Prima::AbstractSlider
+	Prima::Widget::Fader
+);
+
+{
+my %RNT = (
+	%{Prima::AbstractSlider-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
+);
+sub notification_types { return \%RNT; }
+}
 
 sub profile_default
 {
@@ -1237,6 +1248,11 @@ sub on_paint
 	}
 	my @c3d  = ( $self-> dark3DColor, $self-> light3DColor);
 	my @cht  = ( $self-> hiliteColor, $self-> hiliteBackColor);
+	if ( $enabled ) {
+		my $blend = $self->{mouse_in} ? $self->fader_current_value // 1 : 0;
+		$cht[1] = cl::blend(( map { $self->map_color($_) } ( $clr[1], $cht[1] )), $blend / 2 + .5);
+	}
+
 	my @glyph_deltas = ([$clr[0], 0, 0]);
 	unshift @glyph_deltas, [cl::White, 1, -1] unless $enabled;
 	my $flat = $self-> skin eq 'flat';
@@ -1721,12 +1737,22 @@ sub on_mousemove
 	$self-> notify(q(Track)) if !$self-> {autoTrack} && $ov != $self-> {value};
 }
 
+sub on_mouseenter
+{
+	my $self = shift;
+	$self-> fader_in_mouse_enter;
+	$self-> {mouse_in} = 1;
+}
+
 sub on_mouseleave
 {
 	my $self = shift;
 	$self-> repaint_knob if defined( delete $self->{prelight} );
+	$self-> fader_out_mouse_leave;
 }
 
+sub on_fadeout { delete shift->{mouse_in} }
+
 sub on_keydown
 {
 	my ( $self, $code, $key, $mod) = @_;
@@ -1846,11 +1872,16 @@ sub borderWidth
 
 package Prima::CircularSlider;
 use vars qw(@ISA);
-@ISA = qw(Prima::AbstractSlider Prima::Widget::MouseScroller);
+@ISA = qw(
+	Prima::AbstractSlider
+	Prima::Widget::Fader
+	Prima::Widget::MouseScroller
+);
 
 {
 my %RNT = (
 	%{Prima::AbstractSlider-> notification_types()},
+	%{Prima::Widget::Fader-> notification_types()},
 	Stringify  => nt::Action,
 );
 sub notification_types { return \%RNT; }
@@ -2091,6 +2122,19 @@ sub offset2data
 	return cos($a), sin($a);
 }
 
+sub effective_dial_diameter
+{
+	my $self = shift;
+	my $radx = $self->{radius};
+	my $drad = 5;
+	for my $lw ( 2..4) {
+		$radx -= 100;
+		last if $radx < 0;
+		$drad++;
+	}
+	return $self->{radius} * 2 - $drad;
+}
+
 sub on_paint
 {
 	my ( $self, $canvas) = @_;
@@ -2098,7 +2142,7 @@ sub on_paint
 	my $prelight;
 	if ( $self->enabled ) {
 		@clr = ( $self-> color, $self-> backColor);
-		$prelight = $self->prelight_color($clr[1]) if $self->{prelight};
+		$prelight = $self->fader_prelight_color($self->map_color($clr[1])) if $self->{prelight};
 	} else {
 		@clr = ( $self-> disabledColor, $self-> disabledBackColor);
 	}
@@ -2109,15 +2153,6 @@ sub on_paint
 	( abs($self-> {max} - $self-> {min}), $self-> {min}, $self-> {tickVal},
 	$self-> {tickLen}, $self-> {tickTxt}, $self->{buttonWidth} );
 
-	if ( defined $self-> {singlePaint}) {
-		my @clip1 = @{$self-> {expectedClip}};
-		my @clip2 = $self-> clipRect;
-		my $i;
-		for ( $i = 0; $i < 4; $i++) {
-			$self-> {singlePaint} = undef, last if $clip1[$i] != $clip2[$i];
-		}
-	}
-
 	$canvas-> color( $clr[1]);
 	$canvas-> bar( 0, 0, @size) if !$self-> transparent && !defined $self-> {singlePaint};
 	my $fh  = $canvas-> font-> height;
@@ -2128,15 +2163,9 @@ sub on_paint
 
 	goto AFTER_DIAL unless $self->{show_dial};
 	if ( defined $self-> {singlePaint}) {
-		my $drad = 5;
-		my $radx = $rad;
-		for my $lw ( 2..4) {
-			$radx -= 100;
-			last if $radx < 0;
-			$drad++;
-		}
+		my $drad = $self->effective_dial_diameter;
 		$canvas-> color( $prelight ) if $self->{prelight};
-		$canvas-> fill_ellipse( @cpt[0..1], $rad*2-$drad, $rad*2-$drad);
+		$canvas-> fill_ellipse( @cpt[0..1], $drad, $drad);
 		$canvas-> color( $clr[0]);
 	} else {
 		if ($self->{prelight}) {
@@ -2396,8 +2425,12 @@ sub on_mousemove
 		if ( $self-> enabled ) {
 			my ( undef, $prelight) = $self-> xy2val( $x, $y);
 			if (($prelight // 0) != ($self->{prelight} // 0)) {
-				$self->{prelight} = $prelight;
-				$self->repaint_circle;
+				if ( $prelight ) {
+					$self->fader_in_mouse_enter;
+					$self->{prelight} = $prelight;
+				} else {
+					$self->fader_out_mouse_leave;
+				}
 			}
 		}
 		return;
@@ -2419,11 +2452,9 @@ sub on_mousemove
 	}
 }
 
-sub on_mouseleave
-{
-	my $self = shift;
-	$self-> repaint_circle if defined( delete $self->{prelight} );
-}
+sub on_mouseleave  { shift-> fader_out_mouse_leave }
+sub on_fadeout     { delete shift->{prelight} }
+sub on_faderepaint { shift->repaint_circle }
 
 sub on_mouseclick
 {
@@ -2463,18 +2494,24 @@ sub buttons     {($#_)?$_[0]-> set_buttons     ($_[1]):return $_[0]-> {buttons};
 sub repaint_circle
 {
 	my $self = shift;
-	$self-> {singlePaint} = 1;
-	my $radius = $self->{radius} // 0;
-	my @clip = (
-		int( $self-> {circX} - $radius),
-		int( $self-> {circY} - $radius),
-		int( $self-> {circX} + $radius),
-		int( $self-> {circY} + $radius),
+	return unless $self->{show_dial};
+
+	my $buffer = Prima::DeviceBitmap->new(
+		size      => [ $self-> size ],
+		type      => dbt::Pixmap,
+		font      => $self->font,
 	);
-	$self-> {expectedClip} = \@clip;
-	$self-> invalidate_rect( @clip[0..1], $clip[2]+1, $clip[3]+1);
-	$self-> update_view;
+	return $self->repaint unless $buffer;
+
+	$self-> {singlePaint} = 1;
+	$self-> notify( Paint => $buffer );
 	$self-> {singlePaint} = undef;
+
+	my $drad = $self->effective_dial_diameter;
+	$self-> begin_paint;
+	$self-> region( $self-> new_path-> ellipse( $self->{circX}, $self->{circY}, $drad, $drad)->region);
+	$self-> put_image( 0,0,$buffer );
+	$self-> end_paint;
 }
 
 sub value
@@ -2559,20 +2596,6 @@ sub init
 	return %profile;
 }
 
-sub mask2icon
-{
-	my ( $mask, $color ) = @_;
-	my $bits = Prima::Image->new(
-		size => [ $mask-> size ],
-		type => im::Byte,
-		backColor => $color,
-	);
-	$bits-> clear;
-	my $icon = Prima::Icon-> create_combined($bits, $mask);
-	$icon->premultiply_alpha;
-	return $icon;
-}
-
 sub create_tab
 {
 	my ( $self, $x, $y ) = @_;
@@ -2593,12 +2616,12 @@ sub create_tab
 	$tabend_mask->new_gradient(
 		palette => [cl::Black, cl::White, cl::Black],
 	)->bar(0, 0, $y * 2, 1, 1);
-	my $tabend = mask2icon( $tabend_mask, cl::Black );
+	my $tabend = $tabend_mask->to_colormask(cl::Black);
 
 	$tab_mask-> put_image_indirect( $tabend_mask, 0, 0, $y, 0, $y, 1, $y, 1, rop::SrcOver | rop::ConstantColor);
 	$tab_mask-> put_image_indirect( $tabend_mask, $tab_mask-> width - $y, 0, 0, 0, $y, 1, $y, 1, rop::SrcOver | rop::ConstantColor);
 
-	$self->{cache}->{tab}  = mask2icon( $tab_mask, cl::White )-> bitmap;
+	$self->{cache}->{tab}  = $tab_mask-> to_colormask(cl::White)-> bitmap;
 	$self->{cache}->{tabx} = $tab_mask-> width;
 }
 
