@@ -1,5 +1,5 @@
-# $Id$
 use strict;
+use warnings;
 
 package Prima::Tie::Array;
 use Tie::Array;
@@ -13,7 +13,7 @@ sub TIEARRAY {
 
 sub FETCH {
 	my ($self, $idx) = @_;
-	my ($widget, $property) = @$self; 
+	my ($widget, $property) = @$self;
 	$widget-> $property()-> [$idx];
 }
 
@@ -42,13 +42,13 @@ sub STORESIZE {
 }
 
 
-sub EXISTS 
+sub EXISTS
 {
 	my ( $self, $idx) = ( $_[0], abs($_[1]));
 	return $idx >= 0 && $idx < $self-> FETCHSIZE;
 }
 
-sub DELETE 
+sub DELETE
 {
 }
 
@@ -83,7 +83,7 @@ sub FETCH {
 
 sub STORE {
 	my ($self, $idx, $value) = @_;
-	my $size = $self-> FETCHSIZE; 
+	my $size = $self-> FETCHSIZE;
 	if ( $idx == $size) {
 		if ( $self-> {add_items}) {
 			$self-> {self}-> add_items($value);
@@ -193,13 +193,13 @@ sub SPLICE {
 }
 
 
-sub EXISTS 
+sub EXISTS
 {
 	my ( $self, $idx) = ( $_[0], abs($_[1]));
 	return $idx >= 0 && $idx < $self-> FETCHSIZE;
 }
 
-sub DELETE 
+sub DELETE
 {
 }
 
@@ -222,13 +222,13 @@ sub TIESCALAR {
 
 sub FETCH {
 	my ($self) = @_;
-	my ($widget, $property) = @$self; 
+	my ($widget, $property) = @$self;
 	$widget-> $property();
 }
 
 sub STORE {
 	my ($self, $value) = @_;
-	my ( $widget, $property) = @$self; 
+	my ( $widget, $property) = @$self;
 	$widget-> $property($value);
 	return $value;
 }
@@ -310,7 +310,7 @@ if available.
 =head2 Prima::Tie::items
 
 The class is applicable to C<Prima::ListViewer>, C<Prima::ListBox>,
-C<Prima::Header>, and their descendants, and in limited fashion to
+C<Prima::Widget::Header>, and their descendants, and in limited fashion to
 C<Prima::OutlineViewer> and its descendants C<Prima::StringOutline> and
 C<Prima::Outline>.
 
@@ -320,7 +320,7 @@ The class is applicable to any widget.
 
 =head2 Prima::Tie::value
 
-The class is applicable to C<Prima::GroupBox>, C<Prima::ColorDialog>,
+The class is applicable to C<Prima::GroupBox>, C<Prima::Dialog::ColorDialog>,
 C<Prima::SpinEdit>, C<Prima::Gauge>, C<Prima::Slider>, C<Prima::CircularSlider>,
 and C<Prima::ScrollBar>.
 
