@@ -9,10 +9,19 @@ sub draw_item_background
 	if ( $prelight ) {
 		$back_color //= $canvas-> backColor;
 		my $c = $self-> color;
-		$canvas-> new_gradient(
-			spline   => [ 0.75, 0.25 ],
-			palette  => [ $self->prelight_color($back_color), $back_color ],
-		)-> bar( $left, $bottom, $right, $top, 0 );
+		$back_color = $self->map_color($back_color);
+		$prelight = $self->can('fader_prelight_color') ?
+			$self->fader_prelight_color($back_color) :
+			$self->prelight_color($back_color);
+		if ( $self->skin eq 'flat') {
+			$canvas->color($prelight);
+			$canvas->bar( $left, $bottom, $right, $top);
+		} else {
+			$canvas-> new_gradient(
+				spline   => [ 0.75, 0.25 ],
+				palette  => [ $prelight, $back_color ],
+			)-> bar( $left, $bottom, $right, $top, 0 );
+		}
 		$self-> color($c);
 	} else {
 		$canvas-> backColor($back_color) if $back_color;
