@@ -95,9 +95,9 @@ Application_init( Handle self, HV * profile)
 		sv_free(( SV *) profile);
 	}
 
-	if ( SvTYPE( sv = pget_sv( accelItems)) != SVt_NULL)
+	if ( SvOK( sv = pget_sv( accelItems)))
 		my-> set_accelItems( self, sv);
-	if ( SvTYPE( sv = pget_sv( popupItems)) != SVt_NULL)
+	if ( SvOK( sv = pget_sv( popupItems)))
 		my-> set_popupItems( self, sv);
 	pdelete( accelTable);
 	pdelete( accelItems);
@@ -546,6 +546,31 @@ Application_get_hint_widget( Handle self)
 	return var->  hintWidget;
 }
 
+static Bool
+propagate_skin( Handle owner, Handle self, void * dummy)
+{
+	my-> set_skin( self, var-> skin);
+	return false;
+}
+
+SV *
+Application_skin( Handle self, Bool set, SV *skin)
+{
+	if ( !set) {
+		return newSVsv(var->skin);
+	} else if ( var-> stage <= csFrozen) {
+		if ( var-> skin == skin) {
+			my-> first_that( self, (void*)propagate_skin, NULL);
+			return NULL_SV;
+		}
+		if ( var-> skin )
+			sv_free( var-> skin );
+		var-> skin = SvOK( skin ) ? newSVsv(skin) : newSVpv("default", 0);
+		my-> first_that( self, (void*)propagate_skin, NULL);
+	}
+	return NULL_SV;
+}
+
 static Bool
 icon_notify ( Handle self, Handle child, Handle icon)
 {
@@ -1093,6 +1118,7 @@ Bool   Application_ownerColor( Handle self, Bool set, Bool ownerColor) { return
 Bool   Application_ownerBackColor( Handle self, Bool set, Bool ownerBackColor) { return false; }
 Bool   Application_ownerFont( Handle self, Bool set, Bool ownerFont)   { return false; }
 Bool   Application_ownerShowHint( Handle self, Bool set, Bool ownerShowHint) { return false; }
+Bool   Application_ownerSkin( Handle self, Bool set, Bool ownerSkin)   { return false; }
 Bool   Application_ownerPalette( Handle self, Bool set, Bool ownerPalette) { return false; }
 Bool   Application_clipChildren( Handle self, Bool set, Bool clip)   { return true; }
 Bool   Application_clipOwner( Handle self, Bool set, Bool clip_by_children)   { return false; }
