@@ -257,12 +257,61 @@ Icon_init( Handle self, HV * profile)
 	CORE_INIT_TRANSIENT(Icon);
 }
 
+static Bool
+copy_mask_from_image( Handle self, SV * svmask)
+{
+	Handle h;
+	PImage i;
+	Byte *m, bpp;
+
+	if ( !( h = gimme_the_mate(svmask)) || !kind_of(h, CImage)) {
+		warn("Icon.mask: not a Prima::Image object");
+		return false;
+	}
+	i = (PImage) h;
+	if ( i-> h != var-> h || i-> w != var-> w ) {
+		warn("Icon.mask: mask size doesn't match");
+		return false;
+	}
+
+	bpp = i-> type & imBPP;
+	if (bpp == var-> maskType ) {
+		memcpy( var-> mask, i->data, var->maskSize );
+		return true;
+	}
+
+	if ( bpp != 1 && bpp != 8 ) {
+		/* down/upgrade to imByte */
+		Handle h2;
+		PImage i2;
+		if ( !( h2 = CImage(h)->dup(h)))
+			return false;
+		CImage(h2)->set_type(h2, imByte);
+		i2 = (PImage) h2;
+		if ( !( m = malloc(i2-> dataSize ))) {
+			Object_destroy(h2);
+			return false;
+		}
+		memcpy( m, i2->data, i2->dataSize);
+		Object_destroy(h2);
+		bpp = 8;
+	} else {
+		if ( !( m = malloc(i-> dataSize )))
+			return false;
+		memcpy( m, i->data, i->dataSize);
+	}
+
+	free( var-> mask );
+	var-> mask     = m;
+	var-> maskType = bpp;
+	var-> maskLine = LINE_SIZE( var-> w, bpp );
+	var-> maskSize = var-> maskLine * var-> h;
+	return true;
+}
 
 SV *
 Icon_mask( Handle self, Bool set, SV * svmask)
 {
-	STRLEN maskSize;
-	void * mask;
 	int am = var-> autoMasking;
 	if ( var-> stage > csFrozen) return NULL_SV;
 	if ( !set) {
@@ -274,9 +323,19 @@ Icon_mask( Handle self, Bool set, SV * svmask)
 		SvPOK_only(sv);
 		return sv;
 	}
-	mask = SvPV( svmask, maskSize);
-	if ( is_opt( optInDraw) || maskSize <= 0) return NULL_SV;
-	memcpy( var-> mask, mask, (maskSize > (STRLEN)var-> maskSize) ? (STRLEN)var-> maskSize : maskSize);
+
+	if ( !SvOK(svmask)) return NULL_SV;
+
+	if ( SvROK(svmask)) {
+		if ( !copy_mask_from_image( self, svmask ))
+			return NULL_SV;
+	} else {
+		STRLEN maskSize;
+		void * mask;
+		mask = SvPV( svmask, maskSize);
+		if ( is_opt( optInDraw) || maskSize <= 0) return NULL_SV;
+		memcpy( var-> mask, mask, (maskSize > (STRLEN)var-> maskSize) ? (STRLEN)var-> maskSize : maskSize);
+	}
 	var-> autoMasking = amNone;
 	my-> update_change( self);
 	var-> autoMasking = am;
@@ -323,8 +382,8 @@ Icon_convert_mask( Handle self, int type )
 	switch (type) {
 	case imbpp1:
 		/* downgrade */
-		memset( colorref,     1, 1   );
-		memset( colorref + 1, 0, 255 );
+		memset( colorref,       1, 255);
+		memset( colorref + 255, 0, 1  );
 		for ( i = 0, dst = ret; i < var->h; i++, src += srcLine, dst += dstLine) {
 			memset( dst, 0, dstLine );
 			bc_byte_mono_cr( src, dst, var-> w, colorref);
@@ -343,6 +402,32 @@ Icon_convert_mask( Handle self, int type )
 	return ret;
 }
 
+static void
+ic_mask_downgrade( Handle self )
+{
+	int i, type = var->type & imBPP, bpp = (var->type & imBPP ) / 8;
+	Byte *src = var->data, *mask = var->mask;
+	for ( i = 0; i < var-> h; i++, src += var->lineSize, mask += var->maskLine) {
+		switch (type) {
+		/* remove alpha pixels with mask as bits */
+		case 1: {
+			register Byte *s = src, *m = mask;
+			register unsigned int ls = var->lineSize;
+			while ( ls-- > 0 )
+				*(s++) &= *(m++);
+			break;
+		}
+
+		/* remove alpha pixels with mask as bytes */
+		case 4:
+			bc_a8mask_nibble( mask, src, var->w);
+			break;
+		default:
+			bc_a8mask_multibyte( mask, src, var->w, bpp);
+		}
+	}
+}
+
 int
 Icon_maskType( Handle self, Bool set, int type)
 {
@@ -351,6 +436,10 @@ Icon_maskType( Handle self, Bool set, int type)
 
 	type &= ~imGrayScale;
 	if ( var-> maskType == type) return 0;
+
+	if ( var-> mask && var->maskType == imbpp8 && (var->type & imBPP) != 1)
+		ic_mask_downgrade(self);
+
 	switch ( type ) {
 	case imbpp1:
 	case imbpp8:
@@ -366,6 +455,9 @@ Icon_maskType( Handle self, Bool set, int type)
 		croak("mask type must be either im::bpp1 or im::bpp8");
 	}
 
+	if ( var-> mask && var->maskType == imbpp8 && (var->type & imBPP) == 1)
+		ic_mask_downgrade(self);
+
 	var-> maskType = type;
 	return 1;
 }
@@ -732,19 +824,25 @@ Icon_set( Handle self, HV * profile)
 {
 	dPROFILE;
 
-	if (pexist( maskType)) {
+	if ( pexist( maskType) && pexist( mask )) {
+		SV *svmask   = pget_sv(mask);
 		int maskType = pget_i(maskType);
-		if ( maskType == var-> maskType ) pdelete( maskType );
-	}
-
-	if ( pexist( maskType) && pexist( mask ))
-	{
-		free( var-> mask );
-		var-> mask = NULL;
-		my-> set_maskType( self, pget_i( maskType));
-		my-> set_mask( self, pget_sv( mask));
+		if ( svmask && SvOK(svmask) && SvROK(svmask)) {
+			if ( !copy_mask_from_image(self, svmask))
+				goto NO_MASK;
+			my-> set_maskType( self, maskType);
+		} else if ( maskType != var->maskType) {
+			free( var-> mask );
+			var-> mask = NULL;
+			my-> set_maskType( self, maskType);
+			my-> set_mask( self, svmask);
+		} else {
+			my-> set_mask( self, svmask);
+		}
 		pdelete( maskType);
 		pdelete( mask);
+	NO_MASK:
+		;
 	}
 
 	inherited set ( self, profile);
@@ -950,7 +1048,7 @@ Icon_rotate( Handle self, double degrees, SV * svfill)
 }
 
 Bool
-Icon_matrix_transform( Handle self, Matrix matrix, ColorPixel fill)
+Icon_matrix_transform( Handle self, Matrix matrix, ColorPixel fill, Point *aperture)
 {
 	Bool ok;
 	Image dummy;
@@ -968,10 +1066,10 @@ Icon_matrix_transform( Handle self, Matrix matrix, ColorPixel fill)
 
 	bzero(&icon_fill, sizeof(icon_fill));
 
-	ok = inherited matrix_transform(self, matrix, icon_fill);
+	ok = inherited matrix_transform(self, matrix, icon_fill, aperture);
 	if ( ok ) {
 		Image i;
-		ok = img_2d_transform((Handle) &dummy, matrix, icon_fill, &i );
+		ok = img_2d_transform((Handle) &dummy, matrix, icon_fill, &i, NULL );
 		if ( ok ) {
 			free( var-> mask );
 			var-> mask     = i.data;
