@@ -4,9 +4,7 @@ examples/3d.pl - raycasting demo
 
 =head1 SEE ALSO
 
-This example is a simplified port of
-L<https://www.playfuljs.com/a-first-person-engine-in-265-lines> 
-by Hunter Loftis
+This example is a simplified port of L<https://www.playfuljs.com/a-first-person-engine-in-265-lines> by Hunter Loftis
 
 =cut
 
@@ -20,7 +18,10 @@ my $shade          = 0xff0000;
 my $pi             = atan2(1,0)*2;
 my $twopi          = $pi*2;
 my ( $x, $y, $direction, $paces ) = (15.3,-1.2,$pi/4,0);
-my $wall           = create_wall();
+my $wall           = Prima::StdBitmap::image(0);
+$wall->type(im::Byte);
+$wall->type(8);
+$wall->colormap( map { $_ & $shade } $wall->colormap);
 my @wall_size      = $wall->size;
 my $size           = 32;
 my @grid           = map {(0.3 > rand) ? 1 : 0} 1..$size*$size;
@@ -32,50 +33,8 @@ my $draw_rain      = 1;
 my $light          = 0;
 my $can_alpha      = $::application->can_draw_alpha;
 $wall->data( ~$wall->data) unless $can_alpha;
-$wall = $wall->bitmap if $can_alpha;
 my ( $width, $height, $spacing, $scale, $cast_cache ) ;
 
-sub create_wall
-{
-	my $wall = Prima::Image->new(
-		type => im::Byte,
-		size => [128,128],
-	);
-	$wall->clear;
-	$wall->antialias(1);
-	$wall->lineWidth(0.8);
-	$wall->matrix->scale(0.4,-0.4)->translate(-23,290);
-	my (@o, $path);
-	while (<DATA>) {
-		chomp;
-		my @p = split / /, $_;
-		my $c = pop @p;
-		if ( $c eq 'C') {
-			$path->spline([@o, @p], degree => 3);
-			@o = @p[-2,-1];
-		} elsif ( $c eq 'M') {
-			$path = $wall->new_path;
-			$path->moveto(@o = @p);
-		} elsif ( $c eq 'L') {
-			$path->line(@p);
-		} elsif ( $c eq 'F') {
-			$path->fill;
-			$path = $wall->new_path;
-		} elsif ( $c eq 'S') {
-			$wall->color(0x404040);
-			$path->stroke;
-			$path = $wall->new_path;
-		} elsif ( $c eq 'B') {
-			$wall->color(0);
-		} elsif ( $c eq 'W') {
-			$wall->color(0xffffff);
-		}
-	}
-	$wall->type(8);
-	$wall->colormap( map { $_ & $shade } $wall->colormap);
-	return $wall;
-}
-
 sub rotate
 {
 	$direction = ($direction + $twopi + shift);
@@ -262,8 +221,8 @@ sub draw_weapon
 	$canvas->graphic_context( sub {
 		$canvas->antialias(1);
 		$canvas->matrix->scale( $scale )->translate( $left, $top );
-		$canvas->new_path->spline([90, 0, 40, 80, 0, 190])->spline([0, 200, 50, 90, 100, 0])->
-			fill_gradient( palette => [0,$shade], filler => 'vertical' );
+		$canvas->color((0xcccccc & $shade) | 0x222222);
+		$canvas->new_path->spline([90, 0, 40, 80, 0, 190])->spline([0, 200, 50, 90, 100, 0])->fill;
 		$canvas->color((0x444444 & $shade) | 0x222222);
 		$canvas->new_path->spline([100, 0, 50, 90, 0, 200])->spline([5, 190, 55, 90, 105, 0])->fill;
 	});
@@ -287,23 +246,6 @@ my $w = Prima::MainWindow->new(
 		elsif ( $key == kb::Up	  ) { walk(3*$seconds);	     }
 		elsif ( $key == kb::Down  ) { walk(-3*$seconds);     }
 	},
-	onMouseMove => sub {
-		my ( $self, $mod, $x, $y ) = @_;
-		return unless $self->get_mouse_state;
-		if ($self->{alarm} && !$self->{simulation}) {
-			$self->{alarm}->destroy;
-			undef $self->{alarm};
-		}
-		my $w = $self->width / 2;
-		my $h = $self->height / 2;
-		rotate( $pi * ($x - $w) / $w * $seconds);
-		walk( ($y - $h) / $h * 3 * $seconds);
-		$self->{alarm} //= Prima::Utils::alarm(60, sub {
-			delete $self->{alarm};
-			local $self->{simulation} = 1;
-			$self->mouse_move($mod, $x, $y);
-		});
-	},
 	onPaint => sub {
 		my ( $self, $canvas ) = @_;
 		draw_sky($canvas);
@@ -320,85 +262,4 @@ my $w = Prima::MainWindow->new(
 
 $w->insert(Timer => onTick => sub { $w->repaint }, timeout => 5 )->start;
 
-Prima->run;
-
-__DATA__;
-B
-301 574 M
-301 574 300 571 297 568 296 565 C
-296 565 287 565 290 568 283 572 C
-283 572 284 569 287 558 283 558 C
-283 558 279 558 278 560 275 564 C
-275 564 273 566 270 569 267 571 C
-267 571 269 562 271 553 261 563 C
-261 563 253 570 252 575 246 576 C
-246 576 246 572 245 567 243 564 C
-227 575 L
-243 564 225 577 225 578 221 579 C
-221 579 222 573 223 576 223 566 C
-223 566 223 563 212 552 208 562 C
-208 562 207 564 208 563 206 566 C
-206 566 204 570 197 575 195 580 C
-195 580 198 579 198 579 200 577 C
-205 574 L
-200 577 208 571 208 569 212 566 C
-212 566 222 571 214 575 214 586 C
-214 586 225 586 231 574 238 574 C
-238 574 243 594 256 575 260 570 C
-260 570 260 576 258 577 258 584 C
-258 584 266 583 269 570 277 568 C
-277 568 277 575 275 578 274 585 C
-274 585 282 584 282 575 290 573 C
-290 573 296 576 293 577 299 580 C
-299 580 303 579 306 577 308 575 C
-308 575 308 575 304 583 308 583 C
-308 583 313 583 315 580 318 578 C
-318 578 320 576 323 573 325 572 C
-325 572 326 579 330 584 339 575 C
-339 575 341 573 343 572 343 569 C
-343 569 336 570 340 574 332 574 C
-332 574 331 570 331 569 331 564 C
-331 564 324 564 322 573 314 575 C
-314 575 320 565 332 559 333 554 C
-333 554 327 550 317 564 306 571 C
-306 571 303 573 305 573 301 574 C
-F
-B
-170 540 M
-173 540 L
-170 540 175 545 176 540 174 552 C
-174 552 174 554 174 555 173 558 C
-171 565 L
-173 558 173 582 169 576 167 582 C
-167 582 169 582 171 582 170 587 C
-170 587 170 590 170 589 169 590 C
-169 590 170 592 171 594 171 597 C
-171 597 174 596 173 596 175 595 C
-175 595 179 587 176 592 176 586 C
-176 586 176 582 177 579 181 581 C
-181 581 183 577 187 578 195 573 C
-195 573 207 566 203 552 197 544 C
-193 540 L
-197 544 192 539 193 540 191 539 C
-191 539 185 534 187 537 185 534 C
-185 534 176 534 175 530 170 540 C
-F
-W
-178 540 M
-178 540 186 544 194 551 194 561 C
-194 561 194 570 185 572 178 576 C
-178 576 175 561 188 552 181 544 C
-181 544 178 540 180 542 178 540 C
-178 540 L
-F
-B
-239 549 M
-239 549 239 555 249 553 249 541 C
-249 541 244 541 239 546 239 549 C
-F
-177 635 M
-177 635 166 612 154 551 96 558 C
-96 558 5 570 241 499 356 499 C
-356 499 239 493 157 500 123 509 C
-123 509 106 517 148 522 177 635 C
-S
+run Prima;
