@@ -8,7 +8,8 @@ examples/buttons.pl - Prima button widgets
 
 Demonstrates basic use of Prima toolkit, in particular
 creation of built-in push-buttons and radio-buttons. L<Prima::Buttons>
-A customized button creation with subclassing is exemplified
+
+A customized button creation with subclassing is exemplified.
 
 =cut
 
@@ -92,12 +93,24 @@ sub clone
 
 package main;
 
+sub set_style
+{
+	$_[0]->skin($_[1]);
+	$_[0]->repaint;
+}
+
 my $w = Prima::MainWindow-> create(
 	text   => "Button example",
 	centered  => 1,
 	height    => 300,
 	width     => 400,
 	designScale => [7, 16],
+	menuItems => [
+		['~Skin' => [
+			[ '(classic'  => 'Classic 3D' => \&set_style ],
+			[ ')flat'     => 'Flat'       => \&set_style ],
+		]],
+	],
 );
 $w->insert( "Button",
 	origin => [  50,180], 
@@ -110,10 +123,7 @@ my $l = $w->insert( "UserButton" , origin => [ 250,180], autoRepeat => 1);
 
 $w->insert( "Radio"      , origin => [  50,140]);
 
-my $metafile = Prima::Drawable::Metafile->new( size => [70, 70] );
-$metafile->begin_paint;
-$metafile->lineJoin(lj::Miter);
-$metafile->lineWidth(5);
+
 my $c = 3.14159 * 2 / 7;
 my @pts = map { 35 + int(25 * $_ + .5) } (
 	1,0,
@@ -126,16 +136,20 @@ my @pts = map { 35 + int(25 * $_ + .5) } (
 	1,0,
 );
 
-$metafile->polyline(\@pts);
+my $metafile = Prima::Drawable::Metafile->new( size => [70, 70] );
+$metafile->begin_paint;
+$metafile->antialias(1);
+$metafile->lineJoin(lj::Miter);
+$metafile->call( sub {
+	my ($self, $canvas) = @_;
+	my $f = $canvas->fader_current_value // 0;
+	$canvas->color(cl::blend( $canvas->map_color(cl::Fore), cl::Green, $f));
+	$canvas->lineWidth( 5 * ( 1 - $f) );
+	my $method = ( $f == 1 ) ? 'fillpoly' : 'polyline';
+	$canvas->$method(\@pts);
+});
 $metafile->end_paint;
 
-my $metafile2 = Prima::Drawable::Metafile->new( size => [25, 25] );
-$metafile2->begin_paint;
-$metafile2->color(cl::Green);
-$metafile2->fillWinding(fm::Winding);
-$metafile2->fillpoly(\@pts);
-$metafile2->end_paint;
-
 $w->insert(
 	"Button"     ,
 	origin => [ 50,50],
@@ -143,7 +157,6 @@ $w->insert(
 	image => $metafile,
 	text => '',
 	name => 'Meta',
-	hiliteGlyph => $metafile2,
 );
 
 run Prima;
