@@ -37,7 +37,7 @@ $d =~ s/([s-z])/q(f)x(ord($1)-ord('s'))/ge;
 $d =~ s/(..)/chr hex qq(0x$1)/ge;
 #
 my $sc = $::application-> uiScaling;
-my @images = map { Prima::Image-> new(
+my @images = map { Prima::Image-> create(
 	width    => 40,
 	height   => 40,
 	type     => im::BW,
@@ -89,7 +89,7 @@ my @pointer= map {
 } sv::XPointer, sv::YPointer;
 $pointer[$_] = ( $pointer[$_] - 40 * $sc ) / 2 for 0,1;
 
-my $w = Prima::MainWindow-> new(
+my $w = Prima::MainWindow-> create(
 	name => 'Chess puzzle',
 	size => [ 360 * $sc, 360 * $sc],
 	font => { style => fs::Bold, size => 11,},
@@ -190,13 +190,15 @@ my $w = Prima::MainWindow-> new(
 			$self-> set(
 				color     => cl::White,
 				backColor => cl::Black,
+				rop       => rop::AndPut,
 			);
-			$self-> put_image( $x * $d, $y * $d, $images{$_}, rop::AndPut);
+			$self-> put_image( $x * $d, $y * $d, $images{$_});
 			$self-> set(
 				color     => cl::Black,
 				backColor => $boy[ $y * 8 + $x] ? cl::LightGreen : cl::Green,
+				rop       => rop::XorPut,
 			);
-			$self-> put_image( $x * $d, $y * $d, $images{$_}, rop::XorPut);
+			$self-> put_image( $x * $d, $y * $d, $images{$_});
 		}
 	},
 	onMouseDown => sub {
@@ -228,16 +230,19 @@ my $w = Prima::MainWindow-> new(
 		$and-> begin_paint;
 		$and-> backColor(cl::White);
 		$and-> clear;
-		$and-> put_image( @pointer, $images{$i}, rop::NotSrcAnd);
+		$and-> rop( rop::NotSrcAnd);
+		$and-> put_image( @pointer, $images{$i});
 		$and-> end_paint;
 
 		$xor->type(im::RGB) if $xor->get_bpp == 1 && $::application-> get_system_value( sv::ColorPointer);
 		$xor-> begin_paint;
 		$xor-> set(
 			color      => cl::Black,
-			backColor  => $::application-> get_system_value( sv::ColorPointer) ?  cl::Green : cl::White,
+			backColor  => $::application-> get_system_value( sv::ColorPointer) ?
+					cl::Green : cl::White,
+			rop        => rop::OrPut,
 		);
-		$xor-> put_image( @pointer, $images{$i}, rop::OrPut);
+		$xor-> put_image( @pointer, $images{$i});
 		$xor-> end_paint;
 
 		$xx-> combine( $xor, $and);
@@ -282,4 +287,4 @@ my $w = Prima::MainWindow-> new(
 );
 
 
-Prima->run;
+run Prima;
