@@ -13,8 +13,7 @@ Demonstrates use of a standard L<Prima::InputLine> widget
 use strict;
 use warnings;
 
-use Prima 'InputLine', Application => { name => 'InputLine sample', wantUnicodeInput => 1 };
-use Prima::Bidi;
+use Prima 'InputLine', 'Application';
 
 my $w = Prima::MainWindow->create( size => [ 700, 300]);
 
