@@ -1,39 +1,13 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id: eyes.pl,v 1.8 2005/10/13 17:22:53 dk Exp $
-#
-=pod 
-=item NAME
+=pod
 
-An eyes program clone
+=head1 NAME
 
-=item FEATURES
+examples/eyes.pl - An eyes program clone
+
+=head1 FEATURES
 
 A well-known eyes written in Prima toolkit.
-Demostrates the usage of a shape-extension and a 
+Demostrates the usage of a shape-extension and a
 determination of its support on a system.
 
 Note the menu hide feature - it's activation (^M)
@@ -43,6 +17,7 @@ shape-extension interface.
 =cut
 
 use strict;
+use warnings;
 use Prima;
 use Prima::Application name => 'Eyes';
 
@@ -61,7 +36,7 @@ sub reshape
 	for (0,1) {
 	$sz[$_] = 5 if $sz[$_] < 5;
 	}
-	my $i = Prima::Image-> create( 
+	my $i = Prima::Image-> create(
 		width  => $sz[0],
 		height => $sz[1],
 		type   => im::BW,
@@ -94,7 +69,7 @@ my $x = Prima::MainWindow-> create(
 			["~Reverse colors" => sub {
 				my ( $self, $mit) = @_;
 				$revcolors = $revcolors ? 0 : 1;
-				$self-> menu-> text( $mit, 
+				$self-> menu-> text( $mit,
 					$revcolors ? "~Normal colors" : "~Reverse colors");
 				$self-> color( $revcolors ? cl::White : cl::Black);
 				$self-> backColor( $revcolors ? cl::Black : cl::White);
@@ -113,7 +88,7 @@ my $x = Prima::MainWindow-> create(
 	],
 	size     => [ 200, 300],
 	name     => 'Eyes',
-	onSize   => sub { 
+	onSize   => sub {
 		reshape( $_[0]) if $canshape;
 	},
 	onPaint  => sub {
@@ -132,13 +107,13 @@ my $x = Prima::MainWindow-> create(
 			my $angle = atan2( $dd[1], $dd[0]);
 			my ( $sin, $cos) = ( sin($angle), cos( $angle));
 			my $h = sqrt(
-				($eye[1]*$cos) * ($eye[1]*$cos) + 
+				($eye[1]*$cos) * ($eye[1]*$cos) +
 				($eye[0]*$sin) * ($eye[0]*$sin)
 			);
 			my @da = ( $eye[0] * $eye[1] * $cos / $h, $eye[0] * $eye[1] * $sin / $h);
 			my $dp = sqrt( $dd[0] * $dd[0] + $dd[1] * $dd[1]);
 			my $db = sqrt( $da[0] * $da[0] + $da[1] * $da[1]) * 0.36;
-			my @e = ( $db < $dp) ? ( $db * $cos, $db * $sin) : @dd; 
+			my @e = ( $db < $dp) ? ( $db * $cos, $db * $sin) : @dd;
 			$canvas-> fill_ellipse( @e, $sz[0]* $ball, $sz[1]* $ball * 2);
 			$cc[0] += $sz[0] / 2;
 		}
@@ -149,14 +124,14 @@ $x-> icon( reshape( $x));
 
 my @pp = $x-> pointerPos;
 
-$x-> insert( Timer => 
-timeout => 100,
-onTick => sub {
-	my @pxp = $x-> pointerPos;
-	return if $pxp[0] == $pp[0] && $pxp[1] == $pp[1];
-	$x-> repaint;
-	@pp = @pxp;
-})-> start;
+$x-> insert( Timer =>
+	timeout => 100,
+	onTick => sub {
+		my @pxp = $x-> pointerPos;
+		return if $pxp[0] == $pp[0] && $pxp[1] == $pp[1];
+		$x-> repaint;
+		@pp = @pxp;
+	})-> start;
 $x-> show;
 $x-> select;
 
