@@ -1,36 +1,8 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id$
-#
-
 =pod
 
 =head1 NAME
 
-A key dump example
+examples/keys.pl - A key dump example
 
 =head1 FEATURES
 
@@ -52,7 +24,7 @@ use warnings;
 use Prima;
 use Prima::Buttons;
 use Prima::Label;
-use Prima::FontDialog;
+use Prima::Dialog::FontDialog;
 use Prima::Application;
 
 my $propagate = 1;
@@ -63,22 +35,15 @@ my $w = Prima::MainWindow-> create(
 	size => [500,250],
 	text => 'Keyboard events checker',
 	menuItems => [['~Options' => [
-		[ '*pp' => '~Propagate key event' => sub {
-			$propagate = $propagate ? 0 : 1;
-			$_[0]-> menu-> checked( 'pp', $propagate);
-		}],
-		[ 'rr' => '~Repeat key event' => sub {
-			$repeat = $repeat ? 0 : 1;
-			$_[0]-> menu-> checked( 'rr', $repeat);
-		}],
-		[ ( $::application-> wantUnicodeInput()   ? '*' : '') . # is is on?
-			( $::application-> get_system_value( sv::CanUTF8_Input) ? '' : '-') . # is it writable ?
-			'uu' => '~Unicode input' => sub {
-			$::application-> wantUnicodeInput( $_[0]-> menu-> toggle( 'uu'));
-		}],
+		[ '@*' => '~Propagate key event' => sub { $propagate = $_[2] } ],
+		[ '@'  => '~Repeat key event'    => sub { $repeat    = $_[2] } ],
+		[ '@'.( $::application-> wantUnicodeInput()   ? '*' : '') . # is is on?
+			( $::application-> get_system_value( sv::CanUTF8_Input) ? '' : '-'), # is it writable ?
+			'~Unicode input' => sub { $::application-> wantUnicodeInput($_[2]) },
+		],
 		[],
 		["Set ~font..." => "Ctrl+F" => '^F' => sub {
-			my $d =  $fontDialog ? $fontDialog : Prima::FontDialog-> create(
+			my $d =  $fontDialog ? $fontDialog : Prima::Dialog::FontDialog-> create(
 				logFont => $_[0]-> Label1-> font,
 			);
 			$fontDialog = $d;
