@@ -1,4 +1,4 @@
-=pod 
+=pod
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ Demonstration and test of mouse_event() function usage.
 
 use strict;
 use warnings;
-use Prima qw(Buttons MsgBox StdDlg Application);
+use Prima qw(Buttons MsgBox Dialog::FileDialog Application);
 
 my $state = 'empty';
 my $wtx   = 'Macros';
@@ -85,9 +85,9 @@ my $w = Prima::MainWindow-> create(
 sub tick
 {
 	if ( $state eq 'rec') {
-		push( @data, [ 
-			$::application-> pointerPos, 
-			$::application-> get_mouse_state, 
+		push( @data, [
+			$::application-> pointerPos,
+			$::application-> get_mouse_state,
 			$::application-> get_shift_state
 		]);
 		return;
