@@ -30,7 +30,7 @@ my $tn = $Main->insert('TabbedNotebook',
 );
 
 $tn->insert_to_page(0,'Label',
-	text   => \ "\x{5e9} Some F<1|U<m>onospace text> in a label",
+	text   => \ "\x{5e9} Some L<tip://$0/tip|F<1|U<m>onospace text>> in a L<pod://Prima::Label/SYNOPSIS|label>",
 	autoHeight => 1,
 	hotKey => 'm',
 	backColor => cl::Yellow,
@@ -124,3 +124,11 @@ $tn->insert_to_page(3,'Widget',
 );
 
 run Prima;
+
+=pod
+
+=head1 tip
+
+This is a tooltip!
+
+=cut
