@@ -1,32 +1,4 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id$
-#
-
-=pod 
+=pod
 
 =head1 NAME
 
@@ -40,6 +12,7 @@ and large font output performance.
 =cut
 
 use strict;
+use warnings;
 use Prima;
 use Prima::Application;
 
@@ -218,7 +191,7 @@ my $w = Prima::MainWindow-> create(
 		if ( $showBitmaps) {
 			for ( $ymans = 0; $ymans < $vlines; $ymans++) {
 				my $y = $sz[1] - $vlbminst[ $ymans] * $fh;
-				$c-> put_image( $sz[0] - $vlbmxcol[ $ymans], $y, 
+				$c-> put_image( $sz[0] - $vlbmxcol[ $ymans], $y,
 					$dbms[ $vlbms[ $ymans]]);
 				if ( ++$vlbminst[ $ymans] >= $ymaxstep) {
 					$vlbminst[ $ymans] = 1;
@@ -285,7 +258,7 @@ my $w = Prima::MainWindow-> create(
 				ecolor( $c, $cc, cl::Yellow, 0.5) if $vlsped[ $ymans] > 1;
 				$y = $sz[1] - ($vlinst[ $ymans] - $maxln) * $fh;
 				for ( $i = 0; $i < $maxln; $i++) {
-					$c-> text_out( substr( $smp, $i, 1), 
+					$c-> text_out( substr( $smp, $i, 1),
 						$vlxcol[ $ymans] / $textToBMRatio, $y);
 					$y -= $fh;
 				}
