@@ -1,4 +1,4 @@
-=pod 
+=pod
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ examples/outline.pl - Prima outline widget
 =head1 FEATURES
 
 Demonstrates the basic Prima toolkit usage
-and L<Prima::Outlines> class. 
+and L<Prima::Outlines> class.
 
 =cut
 
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 use Prima qw(Application Outlines);
 
-my $w = Prima::MainWindow-> create( 
+my $w = Prima::MainWindow-> create(
 	size => [ 200, 200],
 	designScale => [7, 16],
 );
@@ -47,7 +47,13 @@ my $o = $w-> insert(
 		['Toogle multi select' => sub {
 			$_[0]-> multiSelect( !$_[0]-> multiSelect);
 		}],
+		[],
+		[Style => [
+			[ '(plusminus' => 'Plus-minus' => sub { $_[0]->style('plusminus') } ],
+			[ '*triangle)' => 'Triangle' => sub { $_[0]->style('triangle') } ],
+		]],
 	],
+	style => 'triangle',
 	multiSelect => 0,
 	extendedSelect => 1,
 	path => '.',
