@@ -1,31 +1,4 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id$
-#
-=pod 
+=pod
 
 =head1 NAME
 
@@ -33,7 +6,7 @@ examples/ownerchange.pl - A recreate functionality example.
 
 =head1 FEATURES
 
-Widgets that change owner dynamically often gets 
+Widgets that change owner dynamically often gets
 recreated internally - one system window gets
 destroyed and another created then. Test the correct
 implementation of Prima owner change functionality.
@@ -41,12 +14,14 @@ implementation of Prima owner change functionality.
 =cut
 
 use strict;
+use warnings;
 use Prima qw(Buttons Application);
 
 my $w = Prima::Window-> create(
 	name       => "D1",
 	text    => "Window Number One",
 	origin     =>  [ 100, 300],
+	designScale => [7, 16],
 	borderStyle=> bs::Sizeable,
 	size       =>  [ 350, 100],
 	backColor  => cl::Green,
@@ -62,12 +37,13 @@ my $w = Prima::Window-> create(
 my $w2 = Prima::Window-> create(
 	name      => "D2",
 	text   => "Window Number Two",
+	designScale => [7, 16],
 	origin    =>  [ 500, 300],
 	size      =>  [ 450, 200],
 	font      => { name=>"System VIO",size=>18},
 	backColor => cl::Yellow,
-	onTimer   => sub { 
-		$_[0]-> backColor(($_[0]-> backColor == cl::Yellow) ? 
+	onTimer   => sub {
+		$_[0]-> backColor(($_[0]-> backColor == cl::Yellow) ?
 			cl::White : cl::Yellow)
 	},
 );
@@ -75,13 +51,11 @@ my $w2 = Prima::Window-> create(
 $w-> insert( Button =>
 	rect => [ 10 ,10, 50, 30],
 	text => "<",
-	font => { height => 18},
 	onClick => sub { $_[0]-> owner-> borderIcons(bi::Minimize|bi::TitleBar)},
 );
 $w-> insert( Button =>
 	rect => [ 60 , 10, 100, 30],
 	text => ">",
-	font => { height => 18},
 	onClick => sub { $_[0]-> owner-> borderIcons(
 		bi::TitleBar|bi::SystemMenu|bi::Minimize|bi::Maximize)},
 );
@@ -92,7 +66,7 @@ $w-> insert( Button =>
 	text  => "Change owner",
 	onClick  => sub {
 		my $oldOwner = $_[0]-> owner;
-		$_[0]-> owner (( $_[0]-> owner-> name eq "D1") ? 
+		$_[0]-> owner (( $_[0]-> owner-> name eq "D1") ?
 			$::application-> D2 : $::application-> D1);
 		my $timer = $::application-> Timer1;
 		if ( $timer-> {win} == $w)
