@@ -149,7 +149,7 @@ typedef struct _PrimaXImage
 #define CACHE_A8             6
 
 typedef struct {
-	int type, alpha;
+	int type, data_mul, mask_mul, alpha_channel;
 	PrimaXImage *image;
 	PrimaXImage *icon;
 } ImageCache;
@@ -703,6 +703,7 @@ typedef struct _UnixGuts
 	Bool                         randr_extension;
 	Bool                         render_extension;
 	Bool                         render_supports_argb32;
+	Bool                         render_matrix_enabled;
 	Bool                         composite_extension;
 	int                          composite_opcode;
 	Bool                         composite_error_triggered;
@@ -1243,7 +1244,10 @@ extern Bool
 prima_create_icon_pixmaps( Handle bw_icon, Pixmap *xor, Pixmap *and);
 
 extern ImageCache*
-prima_image_cache( PImage img, int type, int alpha);
+prima_image_cache( PImage img, int type, int data_mul, int mask_mul, int alpha_channel);
+
+#define SIMPLE_IMAGE_CACHE(img,type) prima_image_cache((PImage)(img),type,255,255,0)
+#define IMGDUP_X(d)          X(IMGDUP_H(d))
 
 extern Bool
 prima_put_ximage( XDrawable win, GC gc, PrimaXImage *i,
@@ -1693,9 +1697,6 @@ prima_get_cursor(Handle self);
 extern void
 prima_paint_text_background( Handle self, Point * p, int x, int y );
 
-extern void
-prima_paint_box( Handle self, int w, int h, Matrix matrix, unsigned long foreground );
-
 extern Bool
 prima_update_quarks_cache( Handle self);
 
