@@ -202,6 +202,11 @@ typedef struct {
 	GC            gc;
 	Bool          layered;
 	unsigned long * c;
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	Color         xr_color;
+	Picture       xr_brush;
+	Picture       picture;
+#endif
 } MenuDrawRec;
 
 static void
@@ -852,6 +857,48 @@ store_char( char * src, int srclen, int * srcptr, char * dst, int * dstptr, Bool
 	}
 }
 
+static Bool
+can_antialias( Handle self)
+{
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	if ( !guts.render_extension)
+		return false;
+	self = PComponent(self)->owner;
+	if ( !self ) return false;
+	{
+		DEFXX;
+		if (XT_IS_BITMAP(XX) || (( XT_IS_PIXMAP(XX) || XT_IS_APPLICATION(XX)) && guts.depth==1))
+			return false;
+	}
+	return true;
+#else
+	return false;
+#endif
+}
+
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+static void
+render_fill( PMenuWindow w, MenuDrawRec *draw, Color clr, XPointDouble *pts, int numPts)
+{
+	if ( clr != draw->xr_color ) {
+		XRenderColor c;
+		if ( draw->xr_brush )
+			XRenderFreePicture( DISP, draw->xr_brush );
+		draw->xr_color = clr;
+		c.alpha = 0xffff;
+		c.red   = COLOR_R16(clr);
+		c.green = COLOR_G16(clr);
+		c.blue  = COLOR_B16(clr);
+		draw->xr_brush = XRenderCreateSolidFill (DISP, &c);
+	}
+	my_XRenderCompositeDoublePoly(
+		DISP, PictOpOver, draw->xr_brush, draw->picture,
+		guts.xrender_a8_format,
+		0, 0, 0, 0, pts, numPts, WindingRule
+	);
+}
+#endif
+
 #define DECL_DRAW(name) \
 static Bool \
 menuitem_draw_##name( \
@@ -989,21 +1036,44 @@ DECL_DRAW(submenu)
 	p[1].y = center - ave * 0.6;
 	p[2].x = mx - ave - MENU_CHECK_XOFFSET/2;
 	p[2].y = center + ave * 0.6 + 1;
-	if ( m-> flags. disabled && !selected) {
+	if ( can_antialias(self)) {
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
 		int i;
-		XSetForeground( DISP, draw->gc, draw->c[ciLight3DColor]);
+		XPointDouble pts[3];
 		for ( i = 0; i < 3; i++) {
-			p[i].x++;
-			p[i].y++;
+			pts[i].x = p[i].x;
+			pts[i].y = p[i].y;
 		}
+		if ( m-> flags. disabled && !selected) {
+			for ( i = 0; i < 3; i++) {
+				pts[i].x++;
+				pts[i].y++;
+			}
+			render_fill( w, draw, XX->rgb[ciLight3DColor], pts, 3);
+			for ( i = 0; i < 3; i++) {
+				pts[i].x--;
+				pts[i].y--;
+			}
+		}
+		render_fill( w, draw, clr, pts, 3);
+#endif
+	} else {
+		if ( m-> flags. disabled && !selected) {
+			int i;
+			XSetForeground( DISP, draw->gc, draw->c[ciLight3DColor]);
+			for ( i = 0; i < 3; i++) {
+				p[i].x++;
+				p[i].y++;
+			}
+			XFillPolygon( DISP, win, draw->gc, p, 3, Nonconvex, CoordModeOrigin);
+			for ( i = 0; i < 3; i++) {
+				p[i].x--;
+				p[i].y--;
+			}
+		}
+		XSetForeground( DISP, draw->gc, clr);
 		XFillPolygon( DISP, win, draw->gc, p, 3, Nonconvex, CoordModeOrigin);
-		for ( i = 0; i < 3; i++) {
-			p[i].x--;
-			p[i].y--;
-		}
 	}
-	XSetForeground( DISP, draw->gc, clr);
-	XFillPolygon( DISP, win, draw->gc, p, 3, Nonconvex, CoordModeOrigin);
 	return true;
 }
 
@@ -1011,33 +1081,70 @@ DECL_DRAW(check)
 {
 	int bottom = y + ix->height - MENU_ITEM_GAP - ix-> height * 0.2;
 	int ax = x + MENU_XOFFSET / 2;
-	XGCValues gcv;
-	gcv. line_width = 3;
-	XChangeGC( DISP, draw->gc, GCLineWidth, &gcv);
-	if ( m-> flags. disabled && !selected) {
-		XSetForeground( DISP, draw->gc, draw->c[ciLight3DColor]);
-		XDrawLine( DISP, win, draw->gc, ax + 1 + 1 , y + ix->height / 2 + 1, ax + MENU_XOFFSET - 2 + 1, bottom - 1);
-		XDrawLine( DISP, win, draw->gc, ax + MENU_XOFFSET - 2 + 1, bottom + 1, ax + MENU_CHECK_XOFFSET + 1, y + MENU_ITEM_GAP + ix-> height * 0.2);
+
+	if ( can_antialias(self)) {
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+		DEFMM;
+		XPointDouble pts[] = {
+			{ax,                          y + ix->height/2},
+			{ax + MENU_XOFFSET,           bottom - 2},
+			{ax + MENU_CHECK_XOFFSET,     y + MENU_ITEM_GAP + ix->height * 0.2},
+			{ax + MENU_CHECK_XOFFSET - 2, y + MENU_ITEM_GAP + ix->height * 0.2 + 4},
+			{ax + MENU_XOFFSET,           bottom + 2},
+			{ax + 4,                      y + ix->height/2 + 4}
+		};
+		/* 2 155 7 157 12 152 10 156 7 161 6 159 - very good results */
+
+		if ( m-> flags. disabled && !selected) {
+			int i;
+			XDouble dx = 1.0;
+
+			for ( i = 0; i < 6; i++) {
+				pts[i].x += dx;
+				pts[i].y += dx;
+			}
+			render_fill( w, draw, XX->rgb[ciLight3DColor], pts, 6);
+			for ( i = 0; i < 6; i++) {
+				pts[i].x -= dx;
+				pts[i].y -= dx;
+			}
+		}
+		render_fill( w, draw, clr, pts, 6);
+#endif
+	} else {
+		XGCValues gcv;
+		gcv. line_width = 3;
+		XChangeGC( DISP, draw->gc, GCLineWidth, &gcv);
+		if ( m-> flags. disabled && !selected) {
+			XSetForeground( DISP, draw->gc, draw->c[ciLight3DColor]);
+			XDrawLine( DISP, win, draw->gc, ax + 1 + 1 , y + ix->height / 2 + 1, ax + MENU_XOFFSET - 2 + 1, bottom - 1);
+			XDrawLine( DISP, win, draw->gc, ax + MENU_XOFFSET - 2 + 1, bottom + 1, ax + MENU_CHECK_XOFFSET + 1, y + MENU_ITEM_GAP + ix-> height * 0.2);
+		}
+		XSetForeground( DISP, draw->gc, clr);
+		XDrawLine( DISP, win, draw->gc, ax + 1, y + ix->height / 2, ax + MENU_XOFFSET - 2, bottom);
+		XDrawLine( DISP, win, draw->gc, ax + MENU_XOFFSET - 2, bottom, ax + MENU_CHECK_XOFFSET, y + MENU_ITEM_GAP + ix-> height * 0.2);
+		gcv. line_width = 1;
+		XChangeGC( DISP, draw->gc, GCLineWidth, &gcv);
 	}
-	XSetForeground( DISP, draw->gc, clr);
-	XDrawLine( DISP, win, draw->gc, ax + 1, y + ix->height / 2, ax + MENU_XOFFSET - 2, bottom);
-	XDrawLine( DISP, win, draw->gc, ax + MENU_XOFFSET - 2, bottom, ax + MENU_CHECK_XOFFSET, y + MENU_ITEM_GAP + ix-> height * 0.2);
-	gcv. line_width = 1;
-	XChangeGC( DISP, draw->gc, GCLineWidth, &gcv);
 
 	return true;
 }
 
 DECL_DRAW(checkbox)
 {
-	int 
-		x1 = x  + MENU_XOFFSET / 2 + 1, 
+	int
+		x1 = x  + MENU_XOFFSET / 2 + 1,
 		y1 = y  + (ix-> height/2) - MENU_CHECK_XOFFSET/2 + 1,
 		x2 = x1 + MENU_CHECK_XOFFSET - 2,
 		y2 = y1 + MENU_CHECK_XOFFSET - 2;
 
 	XSetForeground( DISP, draw->gc, draw->c[m->flags.disabled ? ciLight3DColor : (MENU_PALETTE_SIZE-1)]);
-	XDrawLine( DISP, win, draw->gc, x1, y2, x2 + 1, y2);
+	if ( strcmp(CAbstractMenu(self)->owner_skin(self), "flat") == 0 ) {
+		XDrawRectangle( DISP, win, draw->gc, x1, y1, x2-x1, y2-y1);
+		return true;
+	}
+
+	XDrawLine( DISP, win, draw->gc, x1, y2, x2, y2);
 	XDrawLine( DISP, win, draw->gc, x2, y2, x2, y1);
 	XSetForeground( DISP, draw->gc, draw->c[ m->flags.disabled ? ciDisabledText : ciDark3DColor] );
 	XDrawLine( DISP, win, draw->gc, x2, y1, x1, y1);
@@ -1045,7 +1152,7 @@ DECL_DRAW(checkbox)
 
 	x1++; y1++; x2--; y2--;
 	XSetForeground( DISP, draw->gc, draw->c[ m->flags.disabled ? ciDisabledText : ciDark3DColor] );
-	XDrawLine( DISP, win, draw->gc, x1, y2, x2 + 1, y2);
+	XDrawLine( DISP, win, draw->gc, x1, y2, x2, y2);
 	XDrawLine( DISP, win, draw->gc, x2, y2, x2, y1);
 	XSetForeground( DISP, draw->gc, draw->c[ciLight3DColor]);
 	XDrawLine( DISP, win, draw->gc, x2, y1, x1, y1);
@@ -1211,6 +1318,9 @@ typedef struct {
 	XWindow win;
 	Bool layered;
 	Handle self;
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	Picture picture;
+#endif
 } PaintEvent;
 
 DECL_DRAW(custom)
@@ -1218,6 +1328,9 @@ DECL_DRAW(custom)
 	Point offset, size;
 	Event ev = { cmMenuItemPaint };
 	PaintEvent rec = { win, draw-> layered, self };
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	rec.picture = draw->picture;
+#endif
 
 	offset = menu_item_offset( M(self), w, index);
 	size   = menu_item_size( M(self), w, index);
@@ -1317,6 +1430,12 @@ handle_menu_expose( XEvent *ev, XWindow win, Handle self)
 	XCHECKPOINT;
 	CLIP_ARGB_PICTURE(w->argb_picture, rgn);
 
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	draw.picture  = w->argb_picture;
+	draw.xr_color = clInvalid;
+	draw.xr_brush = (Picture) 0;
+#endif
+
 #ifdef USE_XFT
 	if ( !kf-> xft)
 #endif
@@ -1414,6 +1533,10 @@ handle_menu_expose( XEvent *ev, XWindow win, Handle self)
 #ifdef USE_XFT
 	if ( draw. xft_drawable)
 		XftDrawDestroy( draw. xft_drawable);
+#endif
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	if ( draw.xr_brush)
+		XRenderFreePicture(DISP, draw.xr_brush);
 #endif
 	if ( draw. layered ) XFreeGC( DISP, draw. gc);
 	XFlush(DISP);
@@ -2440,7 +2563,7 @@ apc_menu_item_begin_paint( Handle self, PEvent event)
 	YY-> type.widget   = 1;
 	YY-> flags.layered = pe->layered;
 #ifdef HAVE_X11_EXTENSIONS_XRENDER_H
-	YY-> argb_picture  = M(pe->self)->w->argb_picture;
+	YY-> argb_picture  = pe->picture;
 #endif
 	YY-> gdrawable     = pe->win;
 	YY-> size          = event-> gen.P;
