@@ -93,13 +93,16 @@ prima_init_xrender_subsystem(char * error_buf, Bool disable_argb32)
 
 	/* find compat format for putting regular pixmaps */
 	if (
-		disable_argb32 ||
 		!(guts. xrender_display_format = XRenderFindVisualFormat(DISP, guts.visual.visual))
 	) {
 		guts. xrender_argb32_format = NULL;
 		guts. argb_visual. visual = NULL;
 		guts. argb_depth = 0;
-		return false;
+		return true;
+	}
+
+	if ( disable_argb32 ) {
+		guts. argb_visual. visual = NULL;
 	}
 
 	if ( guts. argb_visual. visual ) {
@@ -256,30 +259,11 @@ pen_create_tile(Handle self, Pixmap tile)
 	XRenderPictureAttributes xrp_attr;
 	xrp_attr.repeat = RepeatNormal;
 
-	if ( !guts.render_supports_argb32) {
-		XX-> fp_render_picture = XRenderCreatePicture( DISP, tile, guts.xrender_display_format, CPRepeat, &xrp_attr);
-		return;
-	}
-
-	if (
-		PDrawable(self)-> fillPatternImage &&
-		PObject(PDrawable(self)->fillPatternImage)->stage == csNormal &&
-		!X(PDrawable(self)-> fillPatternImage)->type.icon
-	) {
-		GC gc;
-		XGCValues gcv;
-
-		gcv.foreground = ((XX->alpha << guts. argb_bits. alpha_range) >> 8) << guts. argb_bits. alpha_shift;
-		if ( ( gc = XCreateGC(DISP, tile, GCForeground, &gcv))) {
-			Point sz = get_pixmap_size( tile );
-			XSetPlaneMask( DISP, gc, guts.argb_bits.alpha_mask);
-			XFillRectangle( DISP, tile, gc, 0, 0, sz.x, sz.y);
-			XFreeGC( DISP, gc);
-			XFLUSH;
-		}
-	}
-
-	XX-> fp_render_picture = XRenderCreatePicture( DISP, tile, guts.xrender_argb32_format, CPRepeat, &xrp_attr);
+	XX-> fp_render_picture = XRenderCreatePicture(
+		DISP, tile,
+		guts.render_supports_argb32 ? guts.xrender_argb32_format : guts.xrender_display_format,
+		CPRepeat, &xrp_attr
+	);
 }
 
 static void
@@ -797,8 +781,11 @@ my_XRenderCompositeDoublePoly (Display		    *dpy,
 
     edges = (Edge *) malloc (npoints * sizeof (Edge) +
 			      ((npoints * npoints + 1) * sizeof (XTrapezoid)));
-    if (!edges)
+    if (!edges) {
+        warn("XRenderCompositeDoublePoly: not enough memory (%d vertices, %ld bytes)\n",
+		npoints, npoints * sizeof (Edge) + ((npoints * npoints + 1) * sizeof (XTrapezoid)));
 	return 0;
+    }
     traps = (XTrapezoid *) (edges + npoints);
     nedges = 0;
     for (i = 0; i <= npoints; i++)
