@@ -411,8 +411,6 @@ process_msg( MSG * msg)
 {
 	Bool postpone_msg_translation = false;
 
-	file_process_events(0,0,0);
-
 	switch ( msg-> message)
 	{
 	case WM_TERMINATE:
@@ -472,7 +470,6 @@ process_msg( MSG * msg)
 		break;
 	case WM_FILE:
 	case WM_FILE_REHASH:
-	case WM_NOOP:
 		file_process_events(msg->message, msg->wParam, msg->lParam);
 		return true;
 	case WM_SIGNAL:
@@ -504,18 +501,6 @@ process_msg( MSG * msg)
 	return true;
 }
 
-Bool
-apc_application_go( Handle self)
-{
-	MSG msg;
-	objCheck false;
-
-	guts. application_stop_signal = false;
-	while ( !guts. application_stop_signal && GetMessage( &msg, NULL, 0, 0) && process_msg( &msg));
-	guts. application_stop_signal = false;
-	return true;
-}
-
 Bool
 hwnd_lock( Bool lock)
 {
@@ -554,11 +539,12 @@ apc_application_sync( void)
 }
 
 Bool
-apc_application_yield(Bool wait_for_event)
+yield(Bool wait_for_event)
 {
 	MSG msg;
 	Bool got_events = false;
 	guts. application_stop_signal = false;
+
 	while ( !guts. application_stop_signal && PeekMessage( &msg, NULL, 0, 0, PM_REMOVE)) {
 		got_events = true;
 		if ( !process_msg( &msg)) {
@@ -566,15 +552,54 @@ apc_application_yield(Bool wait_for_event)
 			return false;
 		}
 	}
+
 	if ( prima_guts.application && wait_for_event && !got_events && !guts. application_stop_signal) {
 		Event ev;
 		ev. cmd = cmIdle;
 		C_APPLICATION-> message( prima_guts.application, &ev);
 		if ( prima_guts.application ) {
-			GetMessage( &msg, NULL, 0, 0);
-			process_msg( &msg);
+			DWORD ret;
+			ret = MsgWaitForMultipleObjectsEx(
+				select_n_handles, select_handles,
+				INFINITE,
+				QS_ALLINPUT | QS_ALLPOSTMESSAGE, MWMO_INPUTAVAILABLE
+			);
+
+			if (
+				( ret >= WAIT_OBJECT_0    && ret < WAIT_OBJECT_0    + select_n_handles ) ||
+				( ret >= WAIT_ABANDONED_0 && ret < WAIT_ABANDONED_0 + select_n_handles )
+			) {
+				ret -= ( ret >= WAIT_ABANDONED_0 ) ? WAIT_ABANDONED_0 : WAIT_OBJECT_0;
+				process_file_msg( select_handles[ret] );
+			} else if ( ret == WAIT_OBJECT_0 + select_n_handles ) {
+				/* GetMessage may block, wait till the next yield() call */
+				return true;
+			} else if ( ret == WAIT_TIMEOUT ) {
+				return true;
+			} else {
+				apiErrRet;
+			}
 		}
 	}
+	return true;
+}
+
+Bool
+apc_application_go( Handle self)
+{
+	objCheck false;
+	guts. application_stop_signal = false;
+	while ( !guts. application_stop_signal && yield(true));
+	guts. application_stop_signal = false;
+	return true;
+}
+
+
+Bool
+apc_application_yield(Bool wait_for_event)
+{
+	if ( !yield(wait_for_event))
+		return false;
 	guts. application_stop_signal = false;
 	return prima_guts.application != NULL_HANDLE;
 }
@@ -1309,7 +1334,7 @@ apc_system_action( const char * params)
 			}
 			h = (fd == 0) ? GetStdHandle(STD_INPUT_HANDLE) : (WINHANDLE) _get_osfhandle(fd);
 			if (
-				ReadConsoleInputExW( h, &ir, 1, &n, flags) == 0 ||
+				read_console_input( h, &ir, 1, &n, flags) == 0 ||
 				n == 0
 			)
 				return NULL;
