@@ -37,6 +37,8 @@ PHash         mgr_myfonts      = NULL; // hash of calls to apc_font_load
 PHash         mgr_menu_bitmaps = NULL; // HBITMAP manager for SetMenuItemBitmaps 
 PHash         mgr_scripts      = NULL; // SCRIPT_CACHE entries per font/script
 DWORD         rc;
+WINHANDLE     select_handles[MAX_SELECT_HANDLES];
+unsigned int  select_n_handles = 0;
 HCURSOR       std_arrow_cursor;
 HBRUSH        std_hollow_brush;
 LinePattern   std_hollow_line_pattern;
@@ -86,6 +88,7 @@ typedef enum _MONITOR_DPI_TYPE {
 static HRESULT (__stdcall *SetProcessDpiAwareness)(PROCESS_DPI_AWARENESS)  = NULL;
 static HRESULT (__stdcall *GetDpiForMonitor)(HMONITOR,MONITOR_DPI_TYPE,UINT*,UINT*) = NULL;
 static HRESULT (__stdcall *DwmIsCompositionEnabled)(BOOL *pfEnabled) = NULL;
+static BOOL    (__stdcall *ReadConsoleInputExW)( WINHANDLE hConsoleInput, PINPUT_RECORD lpBuffer, DWORD nLength, LPDWORD lpNumberOfEventsRead, USHORT wFlags) = NULL;
 
 #if WINVER < 0x0600
 static BOOL    (__stdcall *GetUserPreferredUILanguages)(DWORD dwFlags, PULONG pulNumLanguages, PZZWSTR pwszLanguagesBuffer, PULONG pcchLanguagesBuffer) = NULL;
@@ -103,7 +106,6 @@ my_GetUserPreferredUILanguages(
 	return GetUserPreferredUILanguages(dwFlags, pulNumLanguages, pwszLanguagesBuffer, pcchLanguagesBuffer);
 }
 
-
 void
 dpi_change(void)
 {
@@ -141,6 +143,12 @@ is_dwm_enabled( void )
 	}
 }
 
+Bool
+read_console_input( WINHANDLE hConsoleInput, PINPUT_RECORD lpBuffer, DWORD nLength, LPDWORD lpNumberOfEventsRead, USHORT wFlags)
+{
+	return ReadConsoleInputExW( hConsoleInput, lpBuffer, nLength, lpNumberOfEventsRead, wFlags);
+}
+
 static void
 load_function(HMODULE module, void ** ptr, const char * name)
 {
@@ -260,6 +268,7 @@ window_subsystem_init( char * error_buf)
 		mod = LoadLibrary("KERNEL32.DLL");
 		if ( mod ) {
 			LOAD_FUNC(mod, GetUserPreferredUILanguages);
+			LOAD_FUNC(mod, ReadConsoleInputExW);
 		}
 #endif
 	}
@@ -662,7 +671,7 @@ get_current_timestamp()
 	return ft.dwHighDateTime * 10000 + ft.dwLowDateTime / 10000 - guts.program_start_ts;
 }
 
-static Byte
+static uint32_t
 get_mouse_fingerprint( WPARAM mp1 )
 {
 	return
@@ -1714,12 +1723,13 @@ LRESULT CALLBACK layered_frame_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM
 	return generic_frame_handler( win, msg, mp1, mp2 );
 }
 
-static Bool kill_img_cache( Handle self, int keyLen, void * key, void * killDBM)
+static Bool
+kill_img_cache( void* self, int keyLen, void * key, void * killDBM)
 {
 	if ( is_apt( aptDeviceBitmap)) {
-		if ( killDBM) dbm_recreate( self);
+		if ( killDBM) dbm_recreate((Handle) self);
 	} else
-		image_destroy_cache( self);
+		image_destroy_cache((Handle) self);
 	return false;
 }
 
